###############################################################################
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
###############################################################################
# Licensed Materials - Property of IBM
#
#  5724-T01 5724-S98 5724-T03 5724-S96
#
# (c) Copyright IBM Corp. 2003, 2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################




package UserConfig;

@ISA    = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();

## added to support r5.1
my $r51_rules	   	= do "r51_rules.pm";
my $r51_rules_unpeg	= do "r51_rules_unpeg.pm";

#-------------------------------------------------------------------------------
# The PP rules configured here represent a configuration supporting a PM TP for
# Ericsson MGW, as deployed at a customer site.
#
#-------------------------------------------------------------------------------

################
# JOIN AND UNPEGGER RULES
my @r41_unpeg = (

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit pif files',
		INPUT_FILE_DESCRIPTION                    => [ 			
			'^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', 
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_PlugInUnit',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_GigaBitEthernet',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_IpInterface',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_EtMfg_GigaBitEthernet_IpInterface',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_E1PhysPathTerm
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_E1PhysPathTerm pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_E1PhysPathTerm-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_E1PhysPathTerm',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_E1PhysPathTerm',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_Os155SpiTtp',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_Vc4Ttp',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp
	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_Vc12Ttp',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp_E1Ttp
	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp_E1Ttp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp_E1Ttp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Ess_E1Ttp',
		OUTPUT_FILENAME_START           => 'Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Vc4Ttp_Vc12Ttp_E1Ttp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_InteractiveMessaging_ImBasicMessage
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_InteractiveMessaging_ImBasicMessage pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_InteractiveMessaging_ImBasicMessage-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'InteractiveMessaging_ImBasicMessage',
		OUTPUT_FILENAME_START           => 'InteractiveMessaging_ImBasicMessage',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_InteractiveMessaging_ImMessageComposition
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_InteractiveMessaging_ImMessageComposition pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_InteractiveMessaging_ImMessageComposition-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'InteractiveMessaging_ImMessageComposition',
		OUTPUT_FILENAME_START           => 'InteractiveMessaging_ImMessageComposition',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_IpSystem_IpAccessHostGpb
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_IpAccessHostGpb pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_IpSystem_IpAccessHostGpb-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'IpSystem_IpAccessHostGpb',
		OUTPUT_FILENAME_START           => 'IpSystem_IpAccessHostGpb', 
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_IpSystem_UdpHostMainMsb_IpAccessUdpHostMsb
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_UdpHostMainMsb_IpAccessUdpHostMsb pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_IpSystem_UdpHostMainMsb_IpAccessUdpHostMsb-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'IpSystem_UdpHostMainMsb_IpAccessUdpHostMsb',
		OUTPUT_FILENAME_START           => 'IpSystem_UdpHostMainMsb_IpAccessUdpHostMsb',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MgwApplication
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MgwApplication pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MgwApplication-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MgwApplication',
		OUTPUT_FILENAME_START           => 'MgwApplication',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MgwApplication_Aggregated
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MgwApplication_Aggregated pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MgwApplication_Aggregated-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MgwApplication_Aggregated',
		OUTPUT_FILENAME_START           => 'MgwApplication_Aggregated',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MgwApplication_IpNetwork_RemoteSite
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MgwApplication_IpNetwork_RemoteSite pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MgwApplication_IpNetwork_RemoteSite-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MgwApplication_IpNetwork_RemoteSite',
		OUTPUT_FILENAME_START           => 'MgwApplication_IpNetwork_RemoteSite',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MgwApplication_TdmTermGrp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MgwApplication_TdmTermGrp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MgwApplication_TdmTermGrp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MgwApplication_TdmTermGrp',
		OUTPUT_FILENAME_START           => 'MgwApplication_TdmTermGrp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MgwApplication_Vmgw
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join MgwApplication_Vmgw files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MgwApplication_Vmgw-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MgwApplication_Vmgw',
		OUTPUT_FILENAME_START           => 'MgwApplication_Vmgw',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_AmrService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_AmrService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_AmrService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_AmrService',
		OUTPUT_FILENAME_START           => 'MsProcessing_AmrService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_ContinuityCheckService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_ContinuityCheckService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_ContinuityCheckService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_ContinuityCheckService',
		OUTPUT_FILENAME_START           => 'MsProcessing_ContinuityCheckService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_CsdDigitalService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_CsdDigitalService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_CsdDigitalService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_CsdDigitalService',
		OUTPUT_FILENAME_START           => 'MsProcessing_CsdDigitalService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_CsdGsmFaxService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_CsdGsmFaxService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_CsdGsmFaxService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_CsdGsmFaxService',
		OUTPUT_FILENAME_START           => 'MsProcessing_CsdGsmFaxService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_CsdGsmFhService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_CsdGsmFhService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_CsdGsmFhService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_CsdGsmFhService',
		OUTPUT_FILENAME_START           => 'MsProcessing_CsdGsmFhService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_CsdModemService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_CsdModemService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_CsdModemService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_CsdModemService',
		OUTPUT_FILENAME_START           => 'MsProcessing_CsdModemService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_DtmfReceiverService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_DtmfReceiverService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_DtmfReceiverService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_DtmfReceiverService',
		OUTPUT_FILENAME_START           => 'MsProcessing_DtmfReceiverService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_DtmfSenderService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_DtmfSenderService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_DtmfSenderService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_DtmfSenderService',
		OUTPUT_FILENAME_START           => 'MsProcessing_DtmfSenderService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_EcService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_EcService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_EcService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_EcService',
		OUTPUT_FILENAME_START           => 'MsProcessing_EcService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_EfrService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_EfrService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_EfrService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_EfrService',
		OUTPUT_FILENAME_START           => 'MsProcessing_EfrService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_GttService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_GttService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_GttService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_GttService',
		OUTPUT_FILENAME_START           => 'MsProcessing_GttService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_ImService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_ImService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_ImService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_ImService',
		OUTPUT_FILENAME_START           => 'MsProcessing_ImService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_IpbService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_IpbService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_IpbService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_IpbService',
		OUTPUT_FILENAME_START           => 'MsProcessing_IpbService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_JitterHandlingService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_JitterHandlingService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_JitterHandlingService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', 
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_JitterHandlingService',
		OUTPUT_FILENAME_START           => 'MsProcessing_JitterHandlingService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_MccService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_MccService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_MccService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_MccService',
		OUTPUT_FILENAME_START           => 'MsProcessing_MccService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_MpcService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_MpcService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_MpcService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_MpcService',
		OUTPUT_FILENAME_START           => 'MsProcessing_MpcService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_MsDevicePool
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_MsDevicePool pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_MsDevicePool-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_MsDevicePool',
		OUTPUT_FILENAME_START           => 'MsProcessing_MsDevicePool',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_NrService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_NrService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_NrService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', 
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_NrService',
		OUTPUT_FILENAME_START           => 'MsProcessing_NrService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_TfoService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_TfoService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_TfoService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_TfoService',
		OUTPUT_FILENAME_START           => 'MsProcessing_TfoService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_ToneSenderService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_ToneSenderService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_ToneSenderService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_ToneSenderService',
		OUTPUT_FILENAME_START           => 'MsProcessing_ToneSenderService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_MsProcessing_UpFhService
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_UpFhService pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_MsProcessing_UpFhService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_UpFhService',
		OUTPUT_FILENAME_START           => 'MsProcessing_UpFhService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Aal2PathVccTp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Aal2PathVccTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Aal2PathVccTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Aal2PathVccTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Aal2PathVccTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Aal2Sp_Aal2Ap
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Aal2Sp_Aal2Ap pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Aal2Sp_Aal2Ap-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Aal2Sp_Aal2Ap',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Aal2Sp_Aal2Ap',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_AtmPort
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_AtmPort pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_AtmPort-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_AtmPort',
		OUTPUT_FILENAME_START           => 'TransportNetwork_AtmPort',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_AtmPort_VplTp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_AtmPort_VplTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_AtmPort_VplTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_AtmPort_VplTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_AtmPort_VplTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_AtmPort_VplTp_VpcTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_AtmPort_VplTp_VpcTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp_VclTp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp_VclTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_AtmPort_VplTp_VpcTp_VclTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_AtmPort_VplTp_VpcTp_VclTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_AtmTrafficDescriptor
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_AtmTrafficDescriptor pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_AtmTrafficDescriptor-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_AtmTrafficDescriptor',
		OUTPUT_FILENAME_START           => 'TransportNetwork_AtmTrafficDescriptor',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Mtp2TpItu
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp2TpItu pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Mtp2TpItu-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp2TpItu',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp2TpItu',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Mtp3bSpItu
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Mtp3bSpItu-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Mtp3bSpItu_M3uAssociation
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_M3uAssociation pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Mtp3bSpItu_M3uAssociation-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_M3uAssociation',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_M3uAssociation',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu
	# {
		# RULE_TYPE                                 => 'JOIN',
		# RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu pif files',
		# INPUT_FILE_DESCRIPTION                    => [ 
			# '^(ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		# ],
		# COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		# HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			# qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		# ],
		# OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu',
		# OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu',
		# PRODUCE_PIF                     => 'True',
		# PRODUCE_LIF                     => 0,
		# NON_APPLICABLE_HEADER_COUNTERS  => [],
		# REDUNDANT_COUNTERS              => [],
		# HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	# },

	# JOIN RULE ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSrs
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSrs pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSrs-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_Mtp3bSrs',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_Mtp3bSrs',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# JOIN RULE ManagedElement_TransportNetwork_Sctp
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Sctp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Sctp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Sctp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Sctp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	## [START] # 19/9/2008 # r4.2 upgrade MPM to NA ##################################################
	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Aal1TpVccTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Aal1TpVccTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Aal1TpVccTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Aal1TpVccTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Aal2Sp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Aal2Sp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Aal2Sp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Aal2Sp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Aal5TpVccTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_Aal5TpVccTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Aal5TpVccTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Aal5TpVccTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_RouteParameterGroup_ECRouteParameterSet pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
		'^(ManagedElement_MsProcessing_RouteParameterGroup_ECRouteParameterSet-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', 
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ECRouteParameterSet',
		OUTPUT_FILENAME_START           => 'ECRouteParameterSet',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ip_EthernetLink pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_IpSystem_Ip_EthernetLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'EthernetLink',
		OUTPUT_FILENAME_START           => 'EthernetLink',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_EtMfg_FastEthernet pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_IpSystem_Ip_EthernetLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'FastEthernet',
		OUTPUT_FILENAME_START           => 'FastEthernet',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_ImaGroup pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_IpSystem_Ip_EthernetLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ImaGroup',
		OUTPUT_FILENAME_START           => 'ImaGroup',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_ImaGroup_ImaLink pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_ImaGroup_ImaLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ImaLink',
		OUTPUT_FILENAME_START           => 'ImaLink',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_InteractiveMessaging_ImVariableMessage pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_ImaGroup_ImaLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'InteractiveMessaging_ImVariableMessage',
		OUTPUT_FILENAME_START           => 'InteractiveMessaging_ImVariableMessage',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ip_IpAtmLink pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_ImaGroup_ImaLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'IpAtmLink',
		OUTPUT_FILENAME_START           => 'IpAtmLink',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ip pif files',
		INPUT_FILE_DESCRIPTION                    => [ 
			'^(ManagedElement_TransportNetwork_ImaGroup_ImaLink-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ManagedElement_Ip',
		OUTPUT_FILENAME_START           => 'ManagedElement_Ip',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_GeneralProcessorUnit_MediumAccessUnit pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_GeneralProcessorUnit_MediumAccessUnit-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MediumAccessUnit',
		OUTPUT_FILENAME_START           => 'MediumAccessUnit',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing_InmarsatService pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing_InmarsatService-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsProcessing_InmarsatService',
		OUTPUT_FILENAME_START           => 'MsProcessing_InmarsatService',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_MsDeviceGroup pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_MsDeviceGroup-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'MsDeviceGroup',
		OUTPUT_FILENAME_START           => 'MsDeviceGroup',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_MsProcessing pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_MsProcessing-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ManagedElement_MsProcessing',
		OUTPUT_FILENAME_START           => 'ManagedElement_MsProcessing',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bAp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bAp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		## below is commented, and changed as the next 2 lines, for R5.1
		#OUTPUT_BLOCK_NAME               => 'ManagedElement_TransportNetwork_Mtp3bAp',
		#OUTPUT_FILENAME_START           => 'ManagedElement_TransportNetwork_Mtp3bAp',
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_Mtp3bAp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_Mtp3bAp',
		
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_Mtp3bSrs_Mtp3bSr',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_NniSaalTp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_NniSaalTp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_NniSaalTp',
		OUTPUT_FILENAME_START           => 'TransportNetwork_NniSaalTp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ospf pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_IpSystem_Ospf-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ManagedElement_IpSystem_Ospf',
		OUTPUT_FILENAME_START           => 'ManagedElement_IpSystem_Ospf',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ospf_OspfArea pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_IpSystem_Ospf_OspfArea-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ManagedElement_IpSystem_Ospf_OspfArea',
		OUTPUT_FILENAME_START           => 'ManagedElement_IpSystem_Ospf_OspfArea',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_IpSystem_Ospf_OspfInterface pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_IpSystem_Ospf_OspfInterface-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'ManagedElement_IpSystem_Ospf_OspfInterface',
		OUTPUT_FILENAME_START           => 'ManagedElement_IpSystem_Ospf_OspfInterface',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_SccpSp_SccpScrc_SccpAccountingCriteria pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_SccpSp_SccpScrc_SccpAccountingCriteria-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'SccpAccountingCriteria',
		OUTPUT_FILENAME_START           => 'SccpAccountingCriteria',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_SccpSp_SccpScrc_SccpPolicing pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_SccpSp_SccpScrc_SccpPolicing-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'SccpPolicing',
		OUTPUT_FILENAME_START           => 'SccpPolicing',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_SccpSp pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_SccpSp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'SccpSp',
		OUTPUT_FILENAME_START           => 'SccpSp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_SccpSp_SccpScrc pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_SccpSp_SccpScrc-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'SccpScrc',
		OUTPUT_FILENAME_START           => 'SccpScrc',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	# {
		# RULE_TYPE                                 => 'JOIN',
		# RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpAnsi_Mtp3bSls pif files',
		# INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_Mtp3bSpAnsi_Mtp3bSls-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		# COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		# HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			# qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		# ],
		# OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpAnsi_Mtp3bSls',
		# OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpAnsi_Mtp3bSls',
		# PRODUCE_PIF                     => 'True',
		# PRODUCE_LIF                     => 0,
		# NON_APPLICABLE_HEADER_COUNTERS  => [],
		# REDUNDANT_COUNTERS              => [],
		# HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	# },

	# {
		# RULE_TYPE                                 => 'JOIN',
		# RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu pif files',
		# INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_Mtp3bSpItu_Mtp3bSls_Mtp3bSlItu-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		# COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		# HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			# qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		# ],
		# OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpItu_Mtp3bSls',
		# OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpItu_Mtp3bSls',
		# PRODUCE_PIF                     => 'True',
		# PRODUCE_LIF                     => 0,
		# NON_APPLICABLE_HEADER_COUNTERS  => [],
		# REDUNDANT_COUNTERS              => [],
		# HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	# },

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpAnsi_Mtp3bSrs pif files',
		INPUT_FILE_DESCRIPTION                    => [ 		
			'^(ManagedElement_TransportNetwork_Mtp3bSpAnsi_Mtp3bSrs-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif',
		],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpAnsi_Mtp3bSrs',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpAnsi_Mtp3bSrs',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_TransportNetwork_Mtp3bSpAnsi pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_TransportNetwork_Mtp3bSpAnsi-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'TransportNetwork_Mtp3bSpAnsi',
		OUTPUT_FILENAME_START           => 'TransportNetwork_Mtp3bSpAnsi',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join TransportNetwork_Mtp2TpAnsi files',
		INPUT_FILE_DESCRIPTION                    => [ '^TransportNetwork_Mtp2TpAnsi-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif', ],
		OUTPUT_BLOCK_NAME                         => 'TransportNetwork_Mtp2TpAnsi',
		PRODUCE_PIF                               => 'True',
		PRODUCE_LIF                               => 0,
		COUNTERS_TO_JOIN_ON                       => [qw(nEDistinguishedName_MeContext TransportNetwork Mtp2TpAnsi)],
		OUTPUT_FILENAME_START                     => 'TransportNetwork_Mtp2TpAnsi',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
		REDUNDANT_HEADER_COUNTERS                 => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
	},

	{
		RULE_TYPE               => 'UNPEGGER',
		RULE_DESC               => 'Unpeg TransportNetwork_Mtp2TpAnsi counter values ',
		INPUT_FILE_DESCRIPTION  => '^(TransportNetwork_Mtp2TpAnsi-#-.+?)-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}.*-J.pif',
		INPUT_FILE_DATETIME_KEY => '^TransportNetwork_Mtp2TpAnsi-#-.+?-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
		PEG_FILENAME_PREFIX     => 'SAVED',
		UNPEG_FILENAME_PREFIX   => 'UNPEG',
		UNPEG_FILE_TYPE         => 'HEADER',
		PRODUCE_PIF             => 'True',
		PRODUCE_LIF             => 0,
		KEEP_RAW_GRANULARITY    => 'True',
		MAX_PEG_PIF_AGE         => 'DURATION*4+60',
		CALCULATE_ROLLOVER      => 'True',
		DEFAULT_NULL_VALUE      => '',
		DATETIME_COUNTERS       => {
			STARTTIME => 'StartTime',
			STARTDATE => 'StartDate',
			DURATION  => 'granularityPeriod',
			FORMAT    => 'seconds',
		},
		COUNTERS_TO_SORT_ON => [qw (nEDistinguishedName_MeContext TransportNetwork Mtp2TpAnsi)],
		PEG_COUNTERS        => {
			'pmLocalSIBTime'            => '2147483647',
			'pmNoOfMSUReceived'         => '2147483647',
			'pmNoOfMSUTransmitted'      => '2147483647',
			'pmNoOfNacks'               => '2147483647',
			'pmNoOfReTransmittedOctets' => '2147483647',
			'pmNoOfSIOSIFReceived'      => '2147483647',
			'pmNoOfSIOSIFTransmitted'   => '2147483647',
			'pmNoOfStartedRBCongestion' => '2147483647',
			'pmNoOfSuReceivedInError'   => '2147483647',
			'pmRemoteSIBTime'           => '2147483647',
		}
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join TransportNetwork_Mtp2TpChina files',
		INPUT_FILE_DESCRIPTION                    => [ '^TransportNetwork_Mtp2TpChina-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif', ],
		OUTPUT_BLOCK_NAME                         => 'TransportNetwork_Mtp2TpChina',
		PRODUCE_PIF                               => 'True',
		PRODUCE_LIF                               => 0,
		COUNTERS_TO_JOIN_ON                       => [qw(nEDistinguishedName_MeContext TransportNetwork Mtp2TpChina)],
		OUTPUT_FILENAME_START                     => 'TransportNetwork_Mtp2TpChina',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
		REDUNDANT_HEADER_COUNTERS                 => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
	},
	{
		RULE_TYPE               => 'UNPEGGER',
		RULE_DESC               => 'Unpeg TransportNetwork_Mtp2TpChina counter values ',
		INPUT_FILE_DESCRIPTION  => '^(TransportNetwork_Mtp2TpChina-#-.+?)-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}.*-J.pif',
		INPUT_FILE_DATETIME_KEY => '^TransportNetwork_Mtp2TpChina-#-.+?-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
		PEG_FILENAME_PREFIX     => 'SAVED',
		UNPEG_FILENAME_PREFIX   => 'UNPEG',
		UNPEG_FILE_TYPE         => 'HEADER',
		PRODUCE_PIF             => 'True',
		PRODUCE_LIF             => 0,
		KEEP_RAW_GRANULARITY    => 'True',
		MAX_PEG_PIF_AGE         => 'DURATION*4+60',
		CALCULATE_ROLLOVER      => 'True',
		DEFAULT_NULL_VALUE      => '',
		DATETIME_COUNTERS       => {
			STARTTIME => 'StartTime',
			STARTDATE => 'StartDate',
			DURATION  => 'granularityPeriod',
			FORMAT    => 'seconds',
		},
		COUNTERS_TO_SORT_ON => [qw (nEDistinguishedName_MeContext TransportNetwork Mtp2TpChina)],
		PEG_COUNTERS        => {
			'pmLocalSIBTime'            => '2147483647',
			'pmNoOfMSUReceived'         => '2147483647',
			'pmNoOfMSUTransmitted'      => '2147483647',
			'pmNoOfNacks'               => '2147483647',
			'pmNoOfReTransmittedOctets' => '2147483647',
			'pmNoOfSIOSIFReceived'      => '2147483647',
			'pmNoOfSIOSIFTransmitted'   => '2147483647',
			'pmNoOfStartedRBCongestion' => '2147483647',
			'pmNoOfSuReceivedInError'   => '2147483647',
			'pmRemoteSIBTime'           => '2147483647',
		}
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Sts1SpeTtp',
		OUTPUT_FILENAME_START           => 'Sts1SpeTtp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts3CspeTtp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts3CspeTtp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Sts3CspeTtp',
		OUTPUT_FILENAME_START           => 'Sts3CspeTtp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp_Vt15Ttp_T1Ttp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp_Vt15Ttp_T1Ttp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'T1Ttp',
		OUTPUT_FILENAME_START           => 'T1Ttp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE                                 => 'JOIN',
		RULE_DESC                                 => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_T1PhysPathTerm pif files',
		INPUT_FILE_DESCRIPTION                    => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_T1PhysPathTerm-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON                       => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'T1PhysPathTerm',
		OUTPUT_FILENAME_START           => 'T1PhysPathTerm',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp_Vt15Ttp pif files',
		INPUT_FILE_DESCRIPTION => [ '^(ManagedElement_Equipment_Subrack_Slot_PlugInUnit_ExchangeTerminal_Os155SpiTtp_Sts1SpeTtp_Vt15Ttp-#-[^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I\.pif', ],
		COUNTERS_TO_JOIN_ON    => [qw(measObjInstId)],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [
			qw(nEDistinguishedName_MeContext collectionBeginTime_Date collectionBeginTime_Time)
		],
		OUTPUT_BLOCK_NAME               => 'Vt15Ttp',
		OUTPUT_FILENAME_START           => 'Vt15Ttp',
		PRODUCE_PIF                     => 'True',
		PRODUCE_LIF                     => 0,
		NON_APPLICABLE_HEADER_COUNTERS  => [],
		REDUNDANT_COUNTERS              => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	},

	## [END] ### 19/9/2008 # r4.2 upgrade MPM to NA ##################################################

	# UNPEGGER RULE
	{
		RULE_TYPE               => 'UNPEGGER',
		RULE_DESC               => 'Unpeg Files counter values',
		INPUT_FILE_DESCRIPTION  => '^(\w+-#-[^-]+)-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}.*-J\.pif',
		INPUT_FILE_DATETIME_KEY => '^\w+-#-[^-]+-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J\.pif',
		PEG_FILENAME_PREFIX     => 'SAVED',
		UNPEG_FILENAME_PREFIX   => 'UNPEG',
		UNPEG_FILE_TYPE         => 'HEADER',
		PRODUCE_PIF             => 'True',
		PRODUCE_LIF             => 0,
		KEEP_RAW_GRANULARITY    => 'True',
		MAX_PEG_PIF_AGE         => 'DURATION*4+60',
		CALCULATE_ROLLOVER      => 'True',
		DEFAULT_NULL_VALUE      => '',	
		DATETIME_COUNTERS 	    => {
			STARTTIME => 'StartTime',
			STARTDATE => 'StartDate',
			DURATION  => 'granularityPeriod',
			FORMAT    => 'seconds',
		},
		COUNTERS_TO_SORT_ON => [qw (nEDistinguishedName_MeContext measObjInstId)],
		PEG_COUNTERS        => {
			'pmAsyncNonTransModemGsm'          => '2147483647',
			'pmAsyncNonTransModemWcdma'        => '2147483647',
			'pmAsyncTransModemGsm'             => '2147483647',
			'pmAtmCnConnLatePktsRatio0'        => '2147483647',
			'pmAtmCnConnLatePktsRatio1'        => '2147483647',
			'pmAtmCnConnLatePktsRatio2'        => '2147483647',
			'pmAtmCnConnLatePktsRatio3'        => '2147483647',
			'pmAtmCnConnLatePktsRatio4'        => '2147483647',
			'pmAtmCnConnLatePktsRatio5'        => '2147483647',
			'pmAtmCnConnLatePktsRatio6'        => '2147483647',
			'pmAtmCnConnMeasuredJitter0'       => '2147483647',
			'pmAtmCnConnMeasuredJitter1'       => '2147483647',
			'pmAtmCnConnMeasuredJitter2'       => '2147483647',
			'pmAtmCnConnMeasuredJitter3'       => '2147483647',
			'pmAtmCnConnMeasuredJitter4'       => '2147483647',
			'pmAtmCnConnMeasuredJitter5'       => '2147483647',
			'pmAtmRanConnLatePktsRatio0'       => '2147483647',
			'pmAtmRanConnLatePktsRatio1'       => '2147483647',
			'pmAtmRanConnLatePktsRatio2'       => '2147483647',
			'pmAtmRanConnLatePktsRatio3'       => '2147483647',
			'pmAtmRanConnLatePktsRatio4'       => '2147483647',
			'pmAtmRanConnLatePktsRatio5'       => '2147483647',
			'pmAtmRanConnLatePktsRatio6'       => '2147483647',
			'pmAtmRanConnMeasuredJitter0'      => '2147483647',
			'pmAtmRanConnMeasuredJitter1'      => '2147483647',
			'pmAtmRanConnMeasuredJitter2'      => '2147483647',
			'pmAtmRanConnMeasuredJitter3'      => '2147483647',
			'pmAtmRanConnMeasuredJitter4'      => '2147483647',
			'pmAtmRanConnMeasuredJitter5'      => '2147483647',
			'pmBitTransSucc'                   => '2147483647',
			'pmBwErrBlocks'                    => '2147483647',
			'pmBwLostCells'                    => '2147483647',
			'pmBwMissinsCells'                 => '2147483647',
			'pmCallAttempts'                   => '2147483647',
			'pmCallsWithRtpPacketLoss0'        => '2147483647',
			'pmCallsWithRtpPacketLoss1'        => '2147483647',
			'pmCallsWithRtpPacketLoss2'        => '2147483647',
			'pmCallsWithRtpPacketLoss3'        => '2147483647',
			'pmCallsWithRtpPacketLoss4'        => '2147483647',
			'pmCallsWithRtpPacketLoss5'        => '2147483647',
			'pmCallsWithRtpPacketLoss6'        => '2147483647',
			'pmConnLatePktsRatio0'             => '2147483647',
			'pmConnLatePktsRatio1'             => '2147483647',
			'pmConnLatePktsRatio2'             => '2147483647',
			'pmConnLatePktsRatio3'             => '2147483647',
			'pmConnLatePktsRatio4'             => '2147483647',
			'pmConnLatePktsRatio5'             => '2147483647',
			'pmConnLatePktsRatio6'             => '2147483647',
			'pmConnMeasuredJitter0'            => '2147483647',
			'pmConnMeasuredJitter1'            => '2147483647',
			'pmConnMeasuredJitter2'            => '2147483647',
			'pmConnMeasuredJitter3'            => '2147483647',
			'pmConnMeasuredJitter4'            => '2147483647',
			'pmConnMeasuredJitter5'            => '2147483647',
			'pmDiscardedEgressCpsPackets'      => '2147483647',
			#'pmDot1qTpVlanPortInDiscardsLink1' => '2147483647',
			#'pmDot1qTpVlanPortInDiscardsLink2' => '2147483647',
			#'pmDot1qTpVlanPortInFrames'        => '2147483647',
			#'pmDot1qTpVlanPortOutFrames'       => '2147483647',
			'pmEgressCpsPackets'               => '2147483647',
			'pmEsCpp'                          => '2147483647',
			'pmEs'                             => '2147483647',
			'pmEsp'                            => '2147483647',
			'pmFailedCallAttempts'             => '2147483647',
			'pmForcedRelease'                  => '2147483647',
			'pmFtmFailGsm'                     => '2147483647',
			'pmFtmFail'                        => '2147483647',
			'pmFtmSuccGsm'                     => '2147483647',
			'pmFtmSucc'                        => '2147483647',
			'pmFwErrBlocks'                    => '2147483647',
			'pmFwLostCells'                    => '2147483647',
			'pmFwMissinsCells'                 => '2147483647',
			'pmGcpNrOfReceivedMessages'        => '2147483647',
			'pmGcpNrOfSentMessages'            => '2147483647',
			'pmGcpSystemUpTime'                => '2147483647',
			'pmGrFcFe'                         => '2147483647',
			'pmGrFc'                           => '2147483647',
			'pmGrUasIma'                       => '2147483647',
			'pmI10ValAslr'                     => '2147483647',
			'pmI10ValAsls'                     => '2147483647',
			'pmI10ValErl'                      => '2147483647',
			'pmI10ValPd'                       => '2147483647',
			'pmI11ValAslr'                     => '2147483647',
			'pmI11ValAsls'                     => '2147483647',
			'pmI11ValErl'                      => '2147483647',
			'pmI11ValPd'                       => '2147483647',
			'pmI12ValAslr'                     => '2147483647',
			'pmI12ValAsls'                     => '2147483647',
			'pmI12ValErl'                      => '2147483647',
			'pmI12ValPd'                       => '2147483647',
			'pmI13ValAslr'                     => '2147483647',
			'pmI13ValAsls'                     => '2147483647',
			'pmI13ValErl'                      => '2147483647',
			'pmI13ValPd'                       => '2147483647',
			'pmI14ValAslr'                     => '2147483647',
			'pmI14ValAsls'                     => '2147483647',
			'pmI14ValErl'                      => '2147483647',
			'pmI14ValPd'                       => '2147483647',
			'pmI15ValAslr'                     => '2147483647',
			'pmI15ValAsls'                     => '2147483647',
			'pmI15ValErl'                      => '2147483647',
			'pmI15ValPd'                       => '2147483647',
			'pmI16ValAslr'                     => '2147483647',
			'pmI16ValAsls'                     => '2147483647',
			'pmI16ValErl'                      => '2147483647',
			'pmI16ValPd'                       => '2147483647',
			'pmI1ValAslr'                      => '2147483647',
			'pmI1ValAsls'                      => '2147483647',
			'pmI1ValErl'                       => '2147483647',
			'pmI1ValPd'                        => '2147483647',
			'pmI2ValAslr'                      => '2147483647',
			'pmI2ValAsls'                      => '2147483647',
			'pmI2ValErl'                       => '2147483647',
			'pmI2ValPd'                        => '2147483647',
			'pmI3ValAslr'                      => '2147483647',
			'pmI3ValAsls'                      => '2147483647',
			'pmI3ValErl'                       => '2147483647',
			'pmI3ValPd'                        => '2147483647',
			'pmI4ValAslr'                      => '2147483647',
			'pmI4ValAsls'                      => '2147483647',
			'pmI4ValErl'                       => '2147483647',
			'pmI4ValPd'                        => '2147483647',
			'pmI5ValAslr'                      => '2147483647',
			'pmI5ValAsls'                      => '2147483647',
			'pmI5ValErl'                       => '2147483647',
			'pmI5ValPd'                        => '2147483647',
			'pmI6ValAslr'                      => '2147483647',
			'pmI6ValAsls'                      => '2147483647',
			'pmI6ValErl'                       => '2147483647',
			'pmI6ValPd'                        => '2147483647',
			'pmI7ValAslr'                      => '2147483647',
			'pmI7ValAsls'                      => '2147483647',
			'pmI7ValErl'                       => '2147483647',
			'pmI7ValPd'                        => '2147483647',
			'pmI8ValAslr'                      => '2147483647',
			'pmI8ValAsls'                      => '2147483647',
			'pmI8ValErl'                       => '2147483647',
			'pmI8ValPd'                        => '2147483647',
			'pmI9ValAslr'                      => '2147483647',
			'pmI9ValAsls'                      => '2147483647',
			'pmI9ValErl'                       => '2147483647',
			'pmI9ValPd'                        => '2147483647',
			'pmIcmpInDestUnreachs'             => '2147483647',
			'pmIcmpInEchoReps'                 => '2147483647',
			'pmIcmpInEchos'                    => '2147483647',
			'pmIcmpInErrors'                   => '2147483647',
			'pmIcmpInMsgs'                     => '2147483647',
			'pmIcmpInParamProbs'               => '2147483647',
			'pmIcmpInRedirects'                => '2147483647',
			'pmIcmpInSrcQuenchs'               => '2147483647',
			'pmIcmpInTimeExcds'                => '2147483647',
			'pmIcmpOutDestUnreachs'            => '2147483647',
			'pmIcmpOutEchoReps'                => '2147483647',
			'pmIcmpOutEchos'                   => '2147483647',
			'pmIcmpOutErrors'                  => '2147483647',
			'pmIcmpOutMsgs'                    => '2147483647',
			'pmIcmpOutParmProbs'               => '2147483647',
			#'pmIfInBroadcastPktsLink1'         => '2147483647',
			#'pmIfInBroadcastPktsLink2'         => '2147483647',
			'pmIfInBroadcastPkts'              => '2147483647',
			#'pmIfInDiscardsLink1'              => '2147483647',
			#'pmIfInDiscardsLink2'              => '2147483647',
			'pmIfInDiscards'                   => '2147483647',
			#'pmIfInErrorsLink1'                => '2147483647',
			#'pmIfInErrorsLink2'                => '2147483647',
			'pmIfInErrors'                     => '2147483647',
			#'pmIfInMulticastPktsLink1'         => '2147483647',
			#'pmIfInMulticastPktsLink2'         => '2147483647',
			'pmIfInMulticastPkts'              => '2147483647',
			#'pmIfInOctetsHi'                   => '2147483647',
			#'pmIfInOctetsLink1Hi'              => '2147483647',
			#'pmIfInOctetsLink1Lo'              => '2147483647',
			#'pmIfInOctetsLink2Hi'              => '2147483647',
			#'pmIfInOctetsLink2Lo'              => '2147483647',
			#'pmIfInOctetsLo'                   => '2147483647',
			#'pmIfInUcastPktsLink1'             => '2147483647',
			#'pmIfInUcastPktsLink2'             => '2147483647',
			'pmIfInUcastPkts'                  => '2147483647',
			#'pmIfInUnknownProtosLink1'         => '2147483647',
			#'pmIfInUnknownProtosLink2'         => '2147483647',
			'pmIfInUnknownProtos'              => '2147483647',
			#'pmIfOutBroadcastPktsLink1'        => '2147483647',
			#'pmIfOutBroadcastPktsLink2'        => '2147483647',
			'pmIfOutBroadcastPkts'             => '2147483647',
			#'pmIfOutDiscardsLink1'             => '2147483647',
			#'pmIfOutDiscardsLink2'             => '2147483647',
			'pmIfOutDiscards'                  => '2147483647',
			#'pmIfOutErrorsLink1'               => '2147483647',
			#'pmIfOutErrorsLink2'               => '2147483647',
			'pmIfOutErrors'                    => '2147483647',
			#'pmIfOutMulticastPktsLink1'        => '2147483647',
			#'pmIfOutMulticastPktsLink2'        => '2147483647',
			'pmIfOutMulticastPkts'             => '2147483647',
			#'pmIfOutOctetsHi'                  => '2147483647',
			#'pmIfOutOctetsLink1Hi'             => '2147483647',
			#'pmIfOutOctetsLink1Lo'             => '2147483647',
			#'pmIfOutOctetsLink2Hi'             => '2147483647',
			#'pmIfOutOctetsLink2Lo'             => '2147483647',
			#'pmIfOutOctetsLo'                  => '2147483647',
			#'pmIfOutUcastPktsLink1'            => '2147483647',
			#'pmIfOutUcastPktsLink2'            => '2147483647',
			'pmIfOutUcastPkts'                 => '2147483647',
			#'pmIfStatsIpAddrErrors'            => '2147483647',
			#'pmIfStatsIpInDiscards'            => '2147483647',
			#'pmIfStatsIpInHdrErrors'           => '2147483647',
			#'pmIfStatsIpInReceives'            => '2147483647',
			#'pmIfStatsIpOutDiscards'           => '2147483647',
			#'pmIfStatsIpOutRequests'           => '2147483647',
			#'pmIfStatsIpUnknownProtos'         => '2147483647',
			'pmIngressCpsPackets'              => '2147483647',
			'pmIpCnConnLatePktsRatio0'         => '2147483647',
			'pmIpCnConnLatePktsRatio1'         => '2147483647',
			'pmIpCnConnLatePktsRatio2'         => '2147483647',
			'pmIpCnConnLatePktsRatio3'         => '2147483647',
			'pmIpCnConnLatePktsRatio4'         => '2147483647',
			'pmIpCnConnLatePktsRatio5'         => '2147483647',
			'pmIpCnConnLatePktsRatio6'         => '2147483647',
			'pmIpCnConnMeasuredJitter0'        => '2147483647',
			'pmIpCnConnMeasuredJitter1'        => '2147483647',
			'pmIpCnConnMeasuredJitter2'        => '2147483647',
			'pmIpCnConnMeasuredJitter3'        => '2147483647',
			'pmIpCnConnMeasuredJitter4'        => '2147483647',
			'pmIpCnConnMeasuredJitter5'        => '2147483647',
			'pmIpFragCreates'                  => '2147483647',
			'pmIpFragFails'                    => '2147483647',
			'pmIpFragOKs'                      => '2147483647',
			'pmIpInAddrErrors'                 => '2147483647',
			'pmIpInDelivers'                   => '2147483647',
			'pmIpInDiscards'                   => '2147483647',
			'pmIpInHdrErrors'                  => '2147483647',
			'pmIpInReceives'                   => '2147483647',
			'pmIpInUnknownProtos'              => '2147483647',
			'pmIpOutDiscards'                  => '2147483647',
			'pmIpOutRequests'                  => '2147483647',
			'pmIpReasmFails'                   => '2147483647',
			'pmIpReasmOKs'                     => '2147483647',
			'pmIpReasmReqds'                   => '2147483647',
			'pmIpReceivedEcnPkts'              => '2147483647',
			'pmIvIma'                          => '2147483647',
			'pmLatePktsAtmCn'                  => '2147483647',
			'pmLatePktsAtmRan'                 => '2147483647',
			'pmLatePktsDueToDeJitter'          => '2147483647',
			'pmLatePktsIpCn'                   => '2147483647',
			'pmLocalSIBTime'                   => '2147483647',
			'pmLostBrCells'                    => '2147483647',
			'pmLostFpmCells'                   => '2147483647',
			'pmModemOFailGsm'                  => '2147483647',
			'pmModemOFail'                     => '2147483647',
			'pmModemOSuccGsm'                  => '2147483647',
			'pmModemOSucc'                     => '2147483647',
			'pmModemTFailGsm'                  => '2147483647',
			'pmModemTFail'                     => '2147483647',
			'pmModemTSuccGsm'                  => '2147483647',
			'pmModemTSucc'                     => '2147483647',
			'pmMsBbe'                          => '2147483647',
			'pmMsEs'                           => '2147483647',
			'pmMsSes'                          => '2147483647',

			#'pmMsUas' => '2147483647',
			'pmNInValid'                                                        => '2147483647',
			'pmNoOfAALINServiceInd'                                             => '2147483647',
			'pmNoOfAALOUTInd'                                                   => '2147483647',
			'pmNoOfAdjacentSPNotAccessible'                                     => '2147483647',
			'pmNoOfAlignmentFailures'                                           => '2147483647',
			'pmNoOfAllSLFailures'                                               => '2147483647',
			'pmNoOfAMROnNbConns'                                                => '2147483647',
			'pmNoOfAspacAckReceived'                                            => '2147483647',
			'pmNoOfAspacAckSent'                                                => '2147483647',
			'pmNoOfAspacReceived'                                               => '2147483647',
			'pmNoOfAspacSent'                                                   => '2147483647',
			'pmNoOfAspdnAckReceived'                                            => '2147483647',
			'pmNoOfAspdnAckSent'                                                => '2147483647',
			'pmNoOfAspdnReceived'                                               => '2147483647',
			'pmNoOfAspdnSent'                                                   => '2147483647',
			'pmNoOfAspiaAckReceived'                                            => '2147483647',
			'pmNoOfAspiaAckSent'                                                => '2147483647',
			'pmNoOfAspiaReceived'                                               => '2147483647',
			'pmNoOfAspiaSent'                                                   => '2147483647',
			'pmNoOfAspupAckReceived'                                            => '2147483647',
			'pmNoOfAspupAckSent'                                                => '2147483647',
			'pmNoOfAspupReceived'                                               => '2147483647',
			'pmNoOfAspupSent'                                                   => '2147483647',
			'pmNoOfCBARec'                                                      => '2147483647',
			'pmNoOfCBASent'                                                     => '2147483647',
			'pmNoOfCBDSent'                                                     => '2147483647',
			'pmNoOfChangeBackDeclRec'                                           => '2147483647',
			'pmNoOfChangeOverRec'                                               => '2147483647',
			'pmNoOfCOAXCARec'                                                   => '2147483647',
			'pmNoOfCOAXCASent'                                                  => '2147483647',
			'pmNoOfCommunicationLost'                                           => '2147483647',
			'pmNoOfCongestions'                                                 => '2147483647',
			'pmNoOfConnectFailure'                                              => '2147483647',
			'pmNoOfControlledRerouteSuccessPerf'                                => '2147483647',
			'pmNoOfCOOXCOSent'                                                  => '2147483647',
			'pmNoOfCREFRecFromNL'                                               => '2147483647',
			'pmNoOfCREFSentToNL'                                                => '2147483647',
			'pmNoOfCRRec'                                                       => '2147483647',
			'pmNoOfCRSent'                                                      => '2147483647',
			'pmNoOfDataMsgRec'                                                  => '2147483647',
			'pmNoOfDataMsgSent'                                                 => '2147483647',
			'pmNoOfDaudMsgRec'                                                  => '2147483647',
			'pmNoOfDaudMsgSent'                                                 => '2147483647',
			'pmNoOfDavaRec'                                                     => '2147483647',
			'pmNoOfDavaSent'                                                    => '2147483647',
			'pmNoOfDiscardedMsgFromBroadToNarrow'                               => '2147483647',
			'pmNoOfDot3StatsFCSErrors'                                          => '2147483647',
			'pmNoOfDot3StatsLateCollisions'                                     => '2147483647',
			'pmNoOfDT1Rec'                                                      => '2147483647',
			'pmNoOfDT1Sent'                                                     => '2147483647',
			'pmNoOfDunaRec'                                                     => '2147483647',
			'pmNoOfDunaSent'                                                    => '2147483647',
			'pmNoOfDupuRec'                                                     => '2147483647',
			'pmNoOfDupuSent'                                                    => '2147483647',
			'pmNoOfECARec'                                                      => '2147483647',
			'pmNoOfECASent'                                                     => '2147483647',
			'pmNoOfECOSent'                                                     => '2147483647',
			'pmNoOfEFROnNbConns'                                                => '2147483647',
			'pmNoOfEmergencyChangeOverRec'                                      => '2147483647',
			'pmNoOfErrorMsgRec'                                                 => '2147483647',
			'pmNoOfErrorMsgSent'                                                => '2147483647',
			'pmNoOfERRRec'                                                      => '2147483647',
			'pmNoOfERRSent'                                                     => '2147483647',
			'pmNoOfForcedRerouteSuccessPerf'                                    => '2147483647',
			'pmNoOfHdrErrors'                                                   => '2147483647',
			'pmNoOfHopCounterViolation'                                         => '2147483647',
			'pmNoOfIfInDiscards'                                                => '2147483647',
			'pmNoOfIfInErrors'                                                  => '2147483647',
			'pmNoOfIfInNUcastPkts'                                              => '2147483647',
			'pmNoOfIfInUcastPkts'                                               => '2147483647',
			'pmNoOfIfOutDiscards'                                               => '2147483647',
			'pmNoOfIfOutNUcastPkts'                                             => '2147483647',
			'pmNoOfIfOutUcastPkts'                                              => '2147483647',
			'pmNoOfIncomingAssocEstabRequestInStateDownWhenStateEstabIsBlocked' => '2147483647',
			'pmNoOfIpAddrErrors'                                                => '2147483647',
			'pmNoOfIpForwDatagrams'                                             => '2147483647',
			'pmNoOfIpInDiscards'                                                => '2147483647',
			'pmNoOfIpInReceives'                                                => '2147483647',
			'pmNoOfIpOutDiscards'                                               => '2147483647',
			'pmNoOfIpReasmOKs'                                                  => '2147483647',
			'pmNoOfIpReasmReqds'                                                => '2147483647',
			'pmNoOfLocalCongestions'                                            => '2147483647',
			'pmNoOfLocalLinkCongestCeaseRec'                                    => '2147483647',
			'pmNoOfLocalLinkCongestRec'                                         => '2147483647',
			'pmNoOfLowerPrioMsgDiscarded'                                       => '2147483647',
			'pmNoOfLUDTRec'                                                     => '2147483647',
			'pmNoOfLUDTSSent'                                                   => '2147483647',
			'pmNoOfM3uaDataMsgDiscarded'                                        => '2147483647',
			'pmNoOfMaxTrialsForAssocActivReached'                               => '2147483647',
			'pmNoOfMaxTrialsForAssocEstabReached'                               => '2147483647',
			'pmNoOfMsg'                                                         => '2147483647',
			'pmNoOfMSUReceived'                                                 => '2147483647',
			'pmNoOfMSURec'                                                      => '2147483647',
			'pmNoOfMSUSent'                                                     => '2147483647',
			'pmNoOfMSUTransmitted'                                              => '2147483647',
			'pmNoOfNacks'                                                       => '2147483647',
			'pmNoOfNoResponses'                                                 => '2147483647',
			'pmNoOfNotifyMsgRec'                                                => '2147483647',
			'pmNoOfOctets'                                                      => '2147483647',
			'pmNoOfOspfIfEvents'                                                => '2147483647',
			'pmNoOfOspfOriginateNewLsas'                                        => '2147483647',
			'pmNoOfOspfRxNewLsas'                                               => '2147483647',
			'pmNoOfOspfSpfRuns'                                                 => '2147483647',
			'pmNoOfOtherErrors'                                                 => '2147483647',
			'pmNoOfPCMOnNbConns'                                                => '2147483647',
			'pmNoOfProtocolErrors'                                              => '2147483647',
			'pmNoOfReceivedSDUs'                                                => '2147483647',
			'pmNoOfRejectMsg'                                                   => '2147483647',
			'pmNoOfRemoteCongestions'                                           => '2147483647',
			'pmNoOfReTransmittedOctets'                                         => '2147483647',
			'pmNoOfRLSDRecFromNL'                                               => '2147483647',
			'pmNoOfRLSDSentToNL'                                                => '2147483647',
			'pmNoOfRoutingFailNetworkCongest'                                   => '2147483647',
			'pmNoOfRoutingFailNoTransAddrOfSuchNature'                          => '2147483647',
			'pmNoOfRoutingFailNoTransSpecificAddr'                              => '2147483647',
			'pmNoOfRoutingFailReasonUnknown'                                    => '2147483647',
			'pmNoOfRoutingFailSubsysUnavail'                                    => '2147483647',
			'pmNoOfRoutingFailUnequippedSubsys'                                 => '2147483647',
			'pmNoOfRoutingFailure'                                              => '2147483647',
			'pmNoOfRoutingFailurePointCodeUnAvail'                              => '2147483647',
			'pmNoOfSconRec'                                                     => '2147483647',
			'pmNoOfSconSent'                                                    => '2147483647',
			'pmNoOfSctpAssociationRestart'                                      => '2147483647',
			'pmNoOfSctpBufOverflow'                                             => '2147483647',
			'pmNoOfSctpCommunicationErr'                                        => '2147483647',
			'pmNoOfSctpNetworkStatusChange'                                     => '2147483647',
			'pmNoOfSctpResumeSending'                                           => '2147483647',
			'pmNoOfSctpSendFailure'                                             => '2147483647',
			'pmNoOfSecondsAccumulatedRouteUnavailable'                          => '2147483647',
			'pmNoOfSentSDUs'                                                    => '2147483647',
			'pmNoOfSequenceDataLosses'                                          => '2147483647',
			'pmNoOfSIOSIFReceived'                                              => '2147483647',
			'pmNoOfSIOSIFTransmitted'                                           => '2147483647',
			'pmNoOfSLTAFirstTimeOutRec'                                         => '2147483647',
			'pmNoOfSLTASecondTimeOutRec'                                        => '2147483647',
			'pmNoOfStartedRBCongestion'                                         => '2147483647',
			'pmNoOfSubsysAllowedSent'                                           => '2147483647',
			'pmNoOfSuccessAssocAbort'                                           => '2147483647',
			'pmNoOfSuccessAssocEstablish'                                       => '2147483647',
			'pmNoOfSuccessAssocShutDown'                                        => '2147483647',
			'pmNoOfSuReceivedInError'                                           => '2147483647',
			'pmNoOfTimerT21WasStarted'                                          => '2147483647',
			'pmNoOfTransferAllowedRec'                                          => '2147483647',
			'pmNoOfTransferControlledRec'                                       => '2147483647',
			'pmNoOfTransferProhibitedRec'                                       => '2147483647',
			'pmNoOfTRARec'                                                      => '2147483647',
			'pmNoOfTRASent'                                                     => '2147483647',
			'pmNoOfUDTRec'                                                      => '2147483647',
			'pmNoOfUDTSent'                                                     => '2147483647',
			'pmNoOfUDTSRec'                                                     => '2147483647',
			'pmNoOfUDTSSent'                                                    => '2147483647',
			'pmNoOfUnsuccessAssocEstablish'                                     => '2147483647',
			'pmNoOfUnsuccessAssocShutDown'                                      => '2147483647',
			'pmNoOfUnsuccessForcedRerouting'                                    => '2147483647',
			'pmNoOfUnsuccReTransmissions'                                       => '2147483647',
			'pmNoOfUPMsgDiscardedDueToRoutingErr'                               => '2147483647',
			'pmNoOfUserPartUnavailRec'                                          => '2147483647',
			'pmNoOfXUDTRec'                                                     => '2147483647',
			'pmNoOfXUDTSent'                                                    => '2147483647',
			'pmNoOfXUDTSRec'                                                    => '2147483647',
			'pmNoOfXUDTSSent'                                                   => '2147483647',
			'pmNormalRelease'                                                   => '2147483647',
			'pmNrOfAal2TermsRej'                                                => '2147483647',
			'pmNrOfAal2TermsReq'                                                => '2147483647',
			'pmNrOfAdmCtrlRejectedConnections'                                  => '2147483647',
			'pmNrOfConnIcmpDestUnreachs'                                        => '2147483647',
			'pmNrOfContextsRej'                                                 => '2147483647',
			'pmNrOfContextsReq'                                                 => '2147483647',
			'pmNrOfEmergencyCalls'                                              => '2147483647',
			'pmNrOfGcpNotifyCsdFaultAEst'                                       => '2147483647',
			'pmNrOfGcpNotifyCsdFaultBEst'                                       => '2147483647',
			'pmNrOfGcpNotifySpeechFaultAEst'                                    => '2147483647',
			'pmNrOfGcpNotifySpeechFaultBEst'                                    => '2147483647',
			'pmNrOfGcpOctetsRec'                                                => '2147483647',
			'pmNrOfGcpOctetsSent'                                               => '2147483647',
			'pmNrOfGcpRetrans'                                                  => '2147483647',
			'pmNrOfGcpSentPendingMess'                                          => '2147483647',
			'pmNrOfGcpTransactionWithMaxRetr'                                   => '2147483647',
			'pmNrOfGcpTransWithMaxPendingMess'                                  => '2147483647',
			'pmNrOfInternalAal2ConnEstabFail'                                   => '2147483647',
			'pmNrOfInvokedGcpLoadControl'                                       => '2147483647',
			'pmNrOfIpTermsRej'                                                  => '2147483647',
			'pmNrOfIpTermsReq'                                                  => '2147483647',
			'pmNrOfIuTermAal2BearEstabFailLoc'                                  => '2147483647',
			'pmNrOfIuTermAal2BearEstabFailRem'                                  => '2147483647',
			'pmNrOfMediaStreamChannelsRejectedDueToCapacity'                    => '2147483647',
			'pmNrOfMediaStreamChannelsReq'                                      => '2147483647',
			'pmNrOfNbOrigAal2BearEstabFailLoc'                                  => '2147483647',
			'pmNrOfNbOrigAal2BearEstabFailRem'                                  => '2147483647',
			'pmNrOfNbTermAal2BearEstabFailLoc'                                  => '2147483647',
			'pmNrOfNbTermAal2BearEstabFailRem'                                  => '2147483647',
			'pmNrOfOrigIpbcpBearPrepRejected'                                   => '2147483647',
			'pmNrOfOrigIpbcpBearSupervTmrExp'                                   => '2147483647',
			'pmNrOfOrigNbInitFaults'                                            => '2147483647',
			'pmNrOfOrigNbInit'                                                  => '2147483647',
			'pmNrOfRecBctpProtocolFailures'                                     => '2147483647',
			'pmNrOfRecFaultyIpbcpAcceptMsg'                                     => '2147483647',
			'pmNrOfRecIpbcpAcceptMsg'                                           => '2147483647',
			'pmNrOfRecIpbcpConfusedMsg'                                         => '2147483647',
			'pmNrOfRecIpbcpRejectMsg'                                           => '2147483647',
			'pmNrOfRecIpbcpRequestMsg'                                          => '2147483647',
			'pmNrOfRejEmcCalls'                                                 => '2147483647',
			'pmNrOfRejsByStaticAdmCtrl'                                         => '2147483647',
			'pmNrOfSentBctpProtocolFailures'                                    => '2147483647',
			'pmNrOfSentIpbcpAcceptMsg'                                          => '2147483647',
			'pmNrOfSentIpbcpConfusedMsg'                                        => '2147483647',
			'pmNrOfSentIpbcpRejectMsg'                                          => '2147483647',
			'pmNrOfSentIpbcpRequestMsg'                                         => '2147483647',
			'pmNrOfTdmTermsRej'                                                 => '2147483647',
			'pmNrOfTdmTermsReq'                                                 => '2147483647',
			'pmNrOfTermIpbcpBearPrepRejected'                                   => '2147483647',
			'pmNrOfTermIpbcpBearSupervTmrExp'                                   => '2147483647',
			'pmNrOfTermIuInit'                                                  => '2147483647',
			'pmNrOfTermIuInitSucc'                                              => '2147483647',
			'pmNrOfTermNbInit'                                                  => '2147483647',
			'pmNrOfTermNbInitSucc'                                              => '2147483647',
			'pmOifIma'                                                          => '2147483647',
			#'pmReceivedAtmCells'                                                => '2147483647',
			'pmRemoteSIBTime'                                                   => '2147483647',
			'pmRtpDiscardedPkts'                                                => '2147483647',
			'pmRtpLostPkts'                                                     => '2147483647',
			'pmRtpReceivedPkts'                                                 => '2147483647',
			'pmRxFcFe'                                                          => '2147483647',
			'pmRxFc'                                                            => '2147483647',
			'pmRxStuffIma'                                                      => '2147483647',
			'pmRxUusImaFe'                                                      => '2147483647',
			'pmRxUusIma'                                                        => '2147483647',
			'pmSctpAborted'                                                     => '2147483647',
			'pmSctpActiveEstab'                                                 => '2147483647',
			'pmSctpPassiveEstab'                                                => '2147483647',
			'pmSctpShutdowns'                                                   => '2147483647',
			'pmSctpStatAssocOutOfBlue'                                          => '2147483647',
			'pmSctpStatChecksumErrorCounter'                                    => '2147483647',
			'pmSctpStatCommResume'                                              => '2147483647',
			'pmSctpStatCommStop'                                                => '2147483647',
			'pmSctpStatFragmentedUserMsg'                                       => '2147483647',
			'pmSctpStatOutOfOrderRecChunks'                                     => '2147483647',
			'pmSctpStatOutOfOrderSendChunks'                                    => '2147483647',
			'pmSctpStatReassembledUserMsg'                                      => '2147483647',
			'pmSctpStatRecChunksDropped'                                        => '2147483647',
			'pmSctpStatRecChunks'                                               => '2147483647',
			'pmSctpStatReceivedControlChunks'                                   => '2147483647',
			'pmSctpStatReceivedPackages'                                        => '2147483647',
			'pmSctpStatRetransChunks'                                           => '2147483647',
			'pmSctpStatSentChunksDropped'                                       => '2147483647',
			'pmSctpStatSentChunks'                                              => '2147483647',
			'pmSctpStatSentControlChunks'                                       => '2147483647',
			'pmSctpStatSentPackages'                                            => '2147483647',
			'pmSecondsWithUnexp'                                                => '2147483647',
			'pmSerDetected'                                                     => '2147483647',
			'pmSerDetectedTotal'                                                => '2147483647',
			'pmSesCpp'                                                          => '2147483647',
			'pmSesImaFe'                                                        => '2147483647',
			'pmSesIma'                                                          => '2147483647',
			'pmSes'                                                             => '2147483647',
			'pmSesp'                                                            => '2147483647',
			'pmSidActivated'                                                    => '2147483647',
			'pmSuccInConnsRemoteQosClassA'                                      => '2147483647',
			'pmSuccInConnsRemoteQosClassB'                                      => '2147483647',
			'pmSuccInConnsRemoteQosClassC'                                      => '2147483647',
			'pmSuccInConnsRemoteQosClassD'                                      => '2147483647',
			'pmSuccOutConnsRemoteQosClassA'                                     => '2147483647',
			'pmSuccOutConnsRemoteQosClassB'                                     => '2147483647',
			'pmSuccOutConnsRemoteQosClassC'                                     => '2147483647',
			'pmSuccOutConnsRemoteQosClassD'                                     => '2147483647',
			'pmSuccTransmittedPktsAtmCn'                                        => '2147483647',
			'pmSuccTransmittedPktsAtmRan'                                       => '2147483647',
			'pmSuccTransmittedPktsIpCn'                                         => '2147483647',
			'pmSuccTransmittedPkts'                                             => '2147483647',
			'pmSyncTransFaxModemGsm'                                            => '2147483647',
			'pmSyncTransModemGsm'                                               => '2147483647',
			'pmTfoAmrNbDroppedCalls'                                            => '2147483647',
			'pmTfoAmrNbEndPointMode'                                            => '2147483647',
			'pmTfoAmrNbEstablishments'                                          => '2147483647',
			'pmTfoAmrNbFallbacks'                                               => '2147483647',
			'pmTfoAmrNbNegotiations'                                            => '2147483647',
			'pmTfoAmrNbReEstablishments'                                        => '2147483647',
			'pmTfoAmrNbReNegotiations'                                          => '2147483647',
			'pmTfoEfrDroppedCalls'                                              => '2147483647',
			'pmTfoEfrEndPointMode'                                              => '2147483647',
			'pmTfoEfrEstablishments'                                            => '2147483647',
			'pmTfoEfrFallbacks'                                                 => '2147483647',
			'pmTfoEfrNegotiations'                                              => '2147483647',
			'pmTfoEfrReEstablishments'                                          => '2147483647',
			'pmTfoEfrReNegotiations'                                            => '2147483647',
			'pmTotalSeizures'                                                   => '2147483647',
			#'pmTransmittedAtmCells'                                             => '2147483647',
			'pmTxFcFe'                                                          => '2147483647',
			'pmTxFc'                                                            => '2147483647',
			'pmTxStuffIma'                                                      => '2147483647',
			'pmTxUusImaFe'                                                      => '2147483647',
			'pmTxUusIma'                                                        => '2147483647',
			'pmUasImaFe'                                                        => '2147483647',
			'pmUasIma'                                                          => '2147483647',

			#'pmUas' => '2147483647',
			'pmUasp'                          => '2147483647',
			'pmUdiFailGsm'                    => '2147483647',
			'pmUdiFail'                       => '2147483647',
			'pmUdiSuccGsm'                    => '2147483647',
			'pmUdiSucc'                       => '2147483647',
			'pmUdpInDatagrams'                => '2147483647',
			'pmUdpInErrors'                   => '2147483647',
			'pmUdpNoPorts'                    => '2147483647',
			'pmUdpOutDatagrams'               => '2147483647',
			'pmUnRecMessages'                 => '2147483647',
			'pmUnRecParams'                   => '2147483647',
			'pmUnsuccCmm'                     => '2147483647',
			'pmUnsuccessfulConnsInternal'     => '2147483647',
			'pmUnSuccInConnsLocalQosClassA'   => '2147483647',
			'pmUnSuccInConnsLocalQosClassB'   => '2147483647',
			'pmUnSuccInConnsLocalQosClassC'   => '2147483647',
			'pmUnSuccInConnsLocalQosClassD'   => '2147483647',
			'pmUnSuccInConnsRemoteQosClassA'  => '2147483647',
			'pmUnSuccInConnsRemoteQosClassB'  => '2147483647',
			'pmUnSuccInConnsRemoteQosClassC'  => '2147483647',
			'pmUnSuccInConnsRemoteQosClassD'  => '2147483647',
			'pmUnSuccOutConnsLocalQosClassA'  => '2147483647',
			'pmUnSuccOutConnsLocalQosClassB'  => '2147483647',
			'pmUnSuccOutConnsLocalQosClassC'  => '2147483647',
			'pmUnSuccOutConnsLocalQosClassD'  => '2147483647',
			'pmUnSuccOutConnsRemoteQosClassA' => '2147483647',
			'pmUnSuccOutConnsRemoteQosClassB' => '2147483647',
			'pmUnSuccOutConnsRemoteQosClassC' => '2147483647',
			'pmUnSuccOutConnsRemoteQosClassD' => '2147483647',
			'pmUnsuccSeizures'                => '2147483647',
			'pmV21Gsm'                        => '2147483647',
			'pmV21'                           => '2147483647',
			'pmV22bisGsm'                     => '2147483647',
			'pmV22bis'                        => '2147483647',
			'pmV22Gsm'                        => '2147483647',
			'pmV22'                           => '2147483647',
			'pmV27ter'                        => '2147483647',
			'pmV29'                           => '2147483647',
			'pmV32bisGsm'                     => '2147483647',
			'pmV32bis'                        => '2147483647',
			'pmV32Gsm'                        => '2147483647',
			'pmV32'                           => '2147483647',
			'pmV34Gsm'                        => '2147483647',
			'pmV34'                           => '2147483647',
			'pmV90Gsm'                        => '2147483647',
			'pmV90'                           => '2147483647',
			'pmVcBbe'                         => '2147483647',
			'pmVcEs'                          => '2147483647',
			'pmVcSes'                         => '2147483647',

			#'pmVcUas' => '2147483647',
			
			## added for r5.1
			'pmIpRanConnLatePktsRatio0' => '2147483647',
			'pmIpRanConnLatePktsRatio1' => '2147483647',
			'pmIpRanConnLatePktsRatio2' => '2147483647',
			'pmIpRanConnLatePktsRatio3' => '2147483647',
			'pmIpRanConnLatePktsRatio4' => '2147483647',
			'pmIpRanConnLatePktsRatio5' => '2147483647',
			'pmIpRanConnLatePktsRatio6' => '2147483647',
			'pmIpRanConnMeasuredJitter0' => '2147483647',
			'pmIpRanConnMeasuredJitter1' => '2147483647',
			'pmIpRanConnMeasuredJitter2' => '2147483647',
			'pmIpRanConnMeasuredJitter3' => '2147483647',
			'pmIpRanConnMeasuredJitter4' => '2147483647',
			'pmIpRanConnMeasuredJitter5' => '2147483647',
			'pmLatePktsIpRan' => '2147483647',
			'pmLatePktsVoIp' => '2147483647',
			'pmSuccTransmittedPktsIpRan' => '2147483647',
			'pmSuccTransmittedPktsVoIp' => '2147483647',
			'pmVoIpConnLatePktsRatio0' => '2147483647',
			'pmVoIpConnLatePktsRatio1' => '2147483647',
			'pmVoIpConnLatePktsRatio2' => '2147483647',
			'pmVoIpConnLatePktsRatio3' => '2147483647',
			'pmVoIpConnLatePktsRatio4' => '2147483647',
			'pmVoIpConnLatePktsRatio5' => '2147483647',
			'pmVoIpConnLatePktsRatio6' => '2147483647',
			'pmVoIpConnMeasuredJitter0' => '2147483647',
			'pmVoIpConnMeasuredJitter1' => '2147483647',
			'pmVoIpConnMeasuredJitter2' => '2147483647',
			'pmVoIpConnMeasuredJitter3' => '2147483647',
			'pmVoIpConnMeasuredJitter4' => '2147483647',
			'pmVoIpConnMeasuredJitter5' => '2147483647',
			'pmVoIpConnMeasuredJitter6' => '2147483647',
			'pmVoIpConnMeasuredJitter7' => '2147483647',
			'pmVoIpConnMeasuredJitter8' => '2147483647',
			
			##added for r5.1
			'pmAverageBwAmrNbPtime20' => '2147483647',
			'pmAverageBwAmrVoipPtime20' => '2147483647',
			'pmAverageBwAmrVoipPtime40' => '2147483647',
			'pmAverageBwAmrWbNbPtime20' => '2147483647',
			'pmAverageBwAmrWbVoipPtime20' => '2147483647',
			'pmAverageBwAmrWbVoipPtime40' => '2147483647',
			'pmAverageBwEfrNbPtime20' => '2147483647',
			'pmAverageBwEfrVoipPtime20' => '2147483647',
			'pmAverageBwEfrVoipPtime40' => '2147483647',
			'pmAverageBwG729Ptime10' => '2147483647',
			'pmAverageBwG729Ptime20' => '2147483647',
			'pmAverageBwG729Ptime30' => '2147483647',
			'pmAverageBwG729Ptime40' => '2147483647',
			'pmAverageBwInmarsatIuPtime20' => '2147483647',
			'pmNrOfAmrWbUnitsRejDueToCapacity' => '2147483647',
			'pmNrOfG729UnitsRejDueToCapacity' => '2147483647',
			'pmNrOfMediaStreamChsUsedAmrWb' => '2147483647',
			'pmNrOfMediaStreamChsUsedG729' => '2147483647',
			'pmNrOfRejsByIslOverload' => '2147483647',
			'pmUsedBandwidthForSiteIntIpTrans' => '2147483647',
			
			## added for r5.1
			'pmConnMeasuredJitter6' => '2147483647',
			'pmConnMeasuredJitter7' => '2147483647',
			'pmConnMeasuredJitter8' => '2147483647',
			'pmConnsOnRemoteSite' => '2147483647',
			'pmNrOfAdmCtrlAcceptedConnections' => '2147483647',
			'pmRtpReceivedDscpCongPackets' => '2147483647',
			'pmRtpReceivedOctetsHi' => '2147483647',
			'pmRtpReceivedOctetsLo' => '2147483647',
			'pmRtpReceivedPktsHi' => '2147483647',
			'pmRtpReceivedPktsLo' => '2147483647',
			'pmRtpSentOctetsHi' => '2147483647',
			'pmRtpSentOctetsLo' => '2147483647',
			'pmRtpSentPktsHi' => '2147483647',
			'pmRtpSentPktsLo' => '2147483647',
			'pmSuccTransmittedPktsHi' => '2147483647',
			'pmSuccTransmittedPktsLo' => '2147483647',
			
			## added for r5.1
			'pmNoOfAmrOnIuConns' => '2147483647',
			'pmNoOfAmrOnVoIpConns' => '2147483647',
			'pmNoOfAmrWbOnIuConns' => '2147483647',
			'pmNoOfAmrWbOnNbConns' => '2147483647',
			'pmNoOfAmrWbOnVoIpConns' => '2147483647',
			'pmNoOfCodecModRej' => '2147483647',
			'pmNoOfCodecModReq' => '2147483647',
			'pmNoOfEfrOnVoIpConns' => '2147483647',
			'pmNoOfG711OnVoIpConns' => '2147483647',
			'pmNrOfG729OnVoIpConns' => '2147483647',
			'pmNrOfIuIpBearerSupervTmrExp' => '2147483647',
			'pmNrOfVoIpBearerSupervTmrExp' => '2147483647',
			
			## added for r5.1
			'pmNoOfSendBufferOctets'    => '2147483647',
			
			## added for r5.1
			'pmNoOfRecUserData'              => '2147483647',
			'pmNoOfSentUserData'             => '2147483647',
			
			## added for r5.1
			'pmNoOfIncAssocEstReqInStateDwnStateEstBlocked'                     => '2147483647',
			
			## added for r5.1
			'pmNoOfIncAssocEstReqInStateDwnStateEstBlocked' => '2147483647',
			'pmNoOfLowerPrioMsgDiscarded' => '2147483647',
			'pmNoOfMaxTrialsForAssocActivReached' => '2147483647',
			'pmNoOfMaxTrialsForAssocEstabReached' => '2147483647',
			'pmNoOfSctpAssociationRestart' => '2147483647',
			'pmNoOfSctpBufOverflow' => '2147483647',
			'pmNoOfSctpCommunicationErr' => '2147483647',
			'pmNoOfSctpNetworkStatusChange' => '2147483647',
			'pmNoOfSctpResumeSending' => '2147483647',
			'pmNoOfSctpSendFailure' => '2147483647',
			'pmNoOfSuccessAssocAbort' => '2147483647',
			'pmNoOfSuccessAssocEstablish' => '2147483647',
			'pmNoOfTimerT21WasStarted' => '2147483647',
			'pmNoOfUnsuccessAssocEstablish' => '2147483647',
			
		},
	},

);

####################################
## ACCUMULATION of TransportNetwork and Mgw RULES
my @r41_rules = (

	#Process atmTrafficDescriptor
	{
		RULE_TYPE              => 'PERLIZE',
		RULE_DESC              => 'Extract ATM Traffic Descriptor',
		INPUT_FILE_DESCRIPTION => '^UNPEG-#-TransportNetwork_AtmPort_VplTp.*-#-J.pif',
		HEADER_COUNTERS_OP     => sub { return 0; },
		DATA_COUNTERS_OP       => sub {
			my $c_ref    = shift;
			my $atm_desc = $c_ref->{atmTrafficDescriptor};
			if ( !defined $atm_desc ) {
				$atm_desc = $c_ref->{atmTrafficDescriptorId};
			}
			if ( defined $atm_desc ) {
				$atm_desc =~ /,AtmTrafficDescriptor=([^,\s]+)/;
				delete $c_ref->{atmTrafficDescriptor};
				delete $c_ref->{atmTrafficDescriptorId};
				$c_ref->{AtmTrafficDescriptor} = $1;
			}
			return 0;
		},
		FILENAME_SUFFIX           => 'PZ',
		REDUNDANT_DATA_COUNTERS   => [],
		REDUNDANT_HEADER_COUNTERS => [],
	},

	#Inject ingress, egress info
	{
		RULE_TYPE              => 'INFOINSERT',
		RULE_DESC              => 'Inject AtmTrafficDescriptor info',
		INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-PZ\.pif',
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-PZ\.pif',
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-PZ\.pif',
		],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [ 'senderName_MeContext', 'collectionBeginTime_Date', 'collectionBeginTime_Time' ],
		NAMES_USED_TO_ID_DATA_RECORD        => ['AtmTrafficDescriptor'],
		INFO_FILE_DESCRIPTION => [ 
			'^UNPEG-#-TransportNetwork_AtmTrafficDescriptor-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J\.pif'
		],

		#INFO_FILE_DESCRIPTION => ['^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-J.pif'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [ 'senderName_MeContext', 'collectionBeginTime_Date', 'collectionBeginTime_Time' ],

		#NAMES_USED_TO_ID_INFORMATION => ['AtmTrafficDescriptor'],
		NAMES_USED_TO_ID_INFORMATION => ['AtmTrafficDescriptorId'],
		REDUNDANT_COUNTERS           => [],
		WRITE_DATA_LINE              => 'True',
		PRODUCE_PIF                  => 'True',
		PRODUCE_LIF                  => 0,
	},

	#Aggregation for TransportNetwork_AtmPort_VplTp_VpcTp_VclTp upto Vpc level
	{
		'RULE_TYPE'              => 'ACCUMULATE',
		'RULE_DESC'              => 'Accumulate the VclTp counters up to Vpc level',
		'INPUT_FILE_DESCRIPTION' => ["^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-.*-#-S\.pif"],
		'PRODUCE_PIF'            => 'True',
		'PRODUCE_LIF'            => 0,
		'COUNTERS_TO_SORT_ON'    => [ 'measObjInstId_AtmPort', 'measObjInstId_VplTp', 'measObjInstId_VpcTp' ],
		'NON_ADDITIVE_COUNTERS'  => [
			'measObjInstId_ManagedElement', 'measObjInstId_AtmPort',          'measObjInstId_AtmTrafficDescriptor', 'measObjInstId_VplTp',
			'measObjInstId_VpcTp',          'measObjInstId_TransportNetwork', 'AtmTrafficDescriptorId',             'AtmTrafficDescriptor',
			'suspectFlag',                  'egressAtmPcr',                   'ingressAtmPcr',
		],
		'REDUNDANT_COUNTERS' => [qw( measObjInstId_VclTp measObjInstId userLabel)],
		'OUTPUT_BLOCK_NAME'  => 'TransportNetwork_AtmPort_VplTp_VpcTp',
	},

	#Inject aggregaeted counters into TransportNetwork_AtmPort_VplTp_VpcTp
	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Inject aggregated counters into TransportNetwork_AtmPort_VplTp_VpcTp',
		INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*TransportNetwork_AtmPort_VplTp_VpcTp-#-A\.pif',
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*J-#-PZ-#-S\.pif'
		],
		OUTPUT_BLOCK_NAME                         => 'TransportNetwork_AtmPort_VplTp_VpcTp',
		PRODUCE_PIF                               => 'True',
		PRODUCE_LIF                               => 0,
		COUNTERS_TO_JOIN_ON                       => [ 'measObjInstId_AtmPort', 'measObjInstId_VplTp', 'measObjInstId_VpcTp' ],
		OUTPUT_FILENAME_START                     => 'TransportNetwork_AtmPort_VplTp_VpcTp',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ 'senderName_MeContext', 'collectionBeginTime_Date', 'collectionBeginTime_Time' ],
		REDUNDANT_DATA_COUNTERS                   => [qw(measObjInstId_VclTp )],
		REDUNDANT_HEADER_COUNTERS                 => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
	},

	{
		'RULE_TYPE'              => 'ACCUMULATE',
		'RULE_DESC'              => 'Accumulate the TDMTermGrp up to MGW level',
		'INPUT_FILE_DESCRIPTION' => ['^UNPEG-#-MgwApplication_TdmTermGrp-.*-#-J.pif'],
		'PRODUCE_PIF'            => 'True',
		'PRODUCE_LIF'            => 0,
		'COUNTERS_TO_SORT_ON'    => ['measObjInstId_MgwApplication'],
		'NON_ADDITIVE_COUNTERS'  => [ 'measObjInstId_ManagedElement', 'measObjInstId_MgwApplication' ],
		'OLD_COUNTER_NAMES'      => [qw(pmNrOfTdmTermsRej pmNrOfTdmTermsReq)],
		'NEW_COUNTER_NAMES'      => [qw(TDMGrp_pmNrOfTdmTermsRej TDMGrp_pmNrOfTdmTermsReq)],
		'REDUNDANT_COUNTERS'     => [ 'pmNrOfTdmTermsBusy', 'measObjInstId', 'measObjInstId_TdmTermGrp', 'userLabel', 'suspectFlag' ],
		'OUTPUT_BLOCK_NAME'      => 'MgwApplication_Aggregated',
	},

	{
		'RULE_TYPE'              => 'ACCUMULATE',
		'RULE_DESC'              => 'Accumulate the Vmgw up to MGW level',
		'INPUT_FILE_DESCRIPTION' => ['^UNPEG-#-MgwApplication_Vmgw-.*-#-J.pif'],
		'PRODUCE_PIF'            => 'True',
		'PRODUCE_LIF'            => 0,
		'COUNTERS_TO_SORT_ON'    => ['measObjInstId_MgwApplication'],
		'NON_ADDITIVE_COUNTERS'  => [ 'measObjInstId_ManagedElement', 'measObjInstId_MgwApplication' ],
		'OLD_COUNTER_NAMES'      => [
			qw(pmNrOfAal2TermsRej pmNrOfAal2TermsReq pmNrOfIpTermsReq pmNrOfIpTermsRej pmNrOfGcpNotifyCsdFaultAEst pmNrOfGcpNotifySpeechFaultAEst )
		],
		'NEW_COUNTER_NAMES' => [
			qw (VMGW_pmNrOfAal2TermsRej VMGW_pmNrOfAal2TermsReq VMGW_pmNrOfIpTermsReq VMGW_pmNrOfIpTermsRej VMGW_pmNrOfGcpNotifyCsdFaultAEst VMGW_pmNrOfGcpNotifySpeechFaultAEst )
		],
		'REDUNDANT_COUNTERS' => [ 'measObjInstId', 'measObjInstId_Vmgw', 'userLabel', 'suspectFlag' ],
		'OUTPUT_BLOCK_NAME'  => 'MgwApplication_Aggregated',
	},

	{
		'RULE_TYPE'              => 'ACCUMULATE',
		'RULE_DESC'              => 'MgwApplication_Aggregated From MgwApplication',
		'INPUT_FILE_DESCRIPTION' => ['^UNPEG-#-MgwApplication-.*-J\.pif'],
		'PRODUCE_PIF'            => 'True',
		'PRODUCE_LIF'            => 0,
		'COUNTERS_TO_SORT_ON'    => ['measObjInstId_MgwApplication'],
		'OUTPUT_BLOCK_NAME'      => 'MgwApplication_Aggregated',
	},

	{
		RULE_TYPE              => 'JOIN',
		RULE_DESC              => 'Join the MgwApplication_Aggregated files',
		INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-MgwApplication-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-MgwApplication_Aggregated-#-A.pif',
			'^UNPEG-#-MgwApplication_Vmgw-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-MgwApplication_Aggregated-#-A.pif',
			'^UNPEG-#-MgwApplication_TdmTermGrp-#-([^-]+-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-#-J-#-MgwApplication_Aggregated-#-A.pif',
		],
		OUTPUT_BLOCK_NAME       => 'MgwApplication_Aggregated',
		PRODUCE_PIF             => 'True',
		PRODUCE_LIF             => 0,
		REDUNDANT_DATA_COUNTERS => [
			# measObjInstId_MgwApplication
			qw(
			  measObjInstId_ManagedElement			  
			  measObjInstId_Vmgw
			  measObjInstId_TdmTermGrp
			  measObjInstId
			  userLabel
			  suspectFlag
			  maxNrOfLicMediaStreamChannels
			  pmGcpNrOfReceivedMessages
			  pmGcpNrOfSentMessages
			  pmGcpSystemUpTime
			  pmUsedBandwidthForIpTransport
			  pmNrOfMediaStreamChannelsReq
			  pmNrOfEmergencyCalls
			  pmNrOfRejsByStaticAdmCtrl
			  pmNrOfRejEmcCalls
			  pmNrOfMediaStreamChannelsBusy
			  pmNrOfTdmTermsBusy pmNrOfTdmTermsRej pmNrOfTdmTermsReq
			  pmNrOfAal2TermsRej
			  pmNrOfAal2TermsReq
			  pmNrOfIpTermsReq
			  pmNrOfIpTermsRej
			  pmNrOfGcpNotifyCsdFaultAEst
			  pmNrOfGcpNotifySpeechFaultAEst
			  pmNrOfIuTermAal2BearEstabFailLoc
			  pmNrOfRecIpbcpRejectMsg
			  pmNrOfTermNbInitSucc
			  pmNrOfRecIpbcpConfusedMsg
			  pmNrOfOrigIpbcpBearSupervTmrExp
			  pmNrOfGcpNotifyCsdFaultBEst
			  pmNrOfNbTermAal2BearEstabFailLoc
			  pmNrOfInternalAal2ConnEstabFail
			  pmNrOfIuTermAal2BearEstabFailRem
			  pmNrOfRecIpbcpAcceptMsg
			  pmNrOfConnIcmpDestUnreachs
			  pmNrOfTermIuInit
			  pmNrOfGcpNotifySpeechFaultBEst
			  pmNrOfTermIpbcpBearPrepRejected
			  pmNrOfNbTermAal2BearEstabFailRem
			  pmNrOfContextsRej
			  pmNrOfGcpRetrans
			  pmNrOfAal2TermsBusy
			  pmNrOfOrigIpbcpBearPrepRejected
			  pmNrOfContextsReq
			  pmNrOfContextsBusy
			  pmNrOfOrigNbInit
			  pmNrOfSentIpbcpRequestMsg
			  pmNrOfRecBctpProtocolFailures
			  pmNrOfTermIuInitSucc
			  pmNrOfGcpOctetsSent
			  pmNrOfIpTermsBusy
			  pmNrOfInvokedGcpLoadControl
			  pmNoOfPCMOnNbConns
			  pmNrOfSentIpbcpRejectMsg
			  pmNrOfSentIpbcpConfusedMsg
			  pmNrOfSentIpbcpAcceptMsg
			  pmNoOfAMROnNbConns
			  pmNrOfTermNbInit
			  pmNrOfRecFaultyIpbcpAcceptMsg
			  pmNoOfEFROnNbConns
			  pmNrOfGcpSentPendingMess
			  pmNrOfGcpTransactionWithMaxRetr
			  pmNrOfGcpOctetsRec
			  pmNrOfOrigNbInitFaults
			  pmNrOfNbOrigAal2BearEstabFailLoc
			  pmNrOfSentBctpProtocolFailures
			  pmNrOfTermIpbcpBearSupervTmrExp
			  pmNrOfRecIpbcpRequestMsg
			  pmNrOfGcpTransWithMaxPendingMess
			  pmNrOfNbOrigAal2BearEstabFailRem
			  )
		],
		COUNTERS_TO_JOIN_ON                       => ['measObjInstId_MgwApplication'],
		OUTPUT_FILENAME_START                     => 'MgwApplication_Aggregated',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ 'nEDistinguishedName_MeContext', 'collectionBeginTime_Date', 'collectionBeginTime_Time' ],
		REDUNDANT_HEADER_COUNTERS                 => [],
		HOURS_TO_WAIT_FOR_PARTNER_FILES           => -1,
	},

);

my @r41_pif2lif = (

	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove unwanted PIFs',
		INPUT_FILE_DESCRIPTION => [
			'.*-I\.pif',
			#'.*-A\.pif',  ## commented on r5.1
			'^(?!Mgw_Aggregated_.*-#-?).*-A\.pif',  ## added for r5.1
			'.*-PZ\.pif',
			'^UNPEG.*TransportNetwork_AtmPort_.*-#-J\.pif',
			#'^(?!SAVED-#-?).*-I.pif'
		],
	},

	{
		RULE_TYPE              => 'PERLIZE',
		RULE_DESC              => 'Move measObjInstId_ in Id values - PERLIZE usage',
		INPUT_FILE_DESCRIPTION => [
			'^UNPEG.*\.pif',
			'^TransportNetwork.*\.pif',
			'^MgwApplication_Aggregated.*\.pif',						
			'^Mgw_Aggregated_.*Mgw_Aggregated_.*A\.pif', ## added for r5.1
			
		],
		DATA_COUNTERS_OP => sub {
			my $c_ref = shift;
			foreach ( keys %$c_ref ) {
				if ( $_ =~ /^measObjInstId_(.*)/ ) {
					$c_ref->{$1} = $c_ref->{$_};
					delete $c_ref->{$_};
				}
				if ( $c_ref->{$_} =~ NULL ) {
					delete $c_ref->{$_};
				}
			}
			
			## added for r5.1
			if ($c_ref->{Aal2Sp}) {
				$c_ref->{Aal2Sp} =~ s/\s+/_/g;
				$c_ref->{Aal2Sp} =~ s/\"+//g;
			}
						
			return 0;
		},
		FILENAME_SUFFIX => 'PZ_FINAL',
		PRODUCE_PIF     => 'True',
		PRODUCE_LIF     => 0,
	},

	{
		RULE_TYPE              => 'PIF_2_LIF',
		RULE_DESC              => 'Write out the LIFs for Everything',
		INPUT_FILE_DESCRIPTION => [ '.*-#-PZ_FINAL\.pif', ],
		PRODUCE_PIF            => 0,
		PRODUCE_LIF            => 'True',
	},

	{
		RULE_TYPE              => 'PIF_REMOVE',
		RULE_DESC              => 'Remove leftover PIFs',
		INPUT_FILE_DESCRIPTION => [ '^UNPEG.*\.pif', ],
	},

);

my @no_rules = ();

sub postparser_config {

	#[ ( @r41_unpeg, @r41_rules, @r41_pif2lif ) ]; ## disabled

	#[ ( @no_rules ) ]; ## for debugging purposes, disabling the UserConfig.pm
	
	## added for r5.1
	[ (@r41_unpeg, @r41_rules, @$r51_rules, @$r51_rules_unpeg, @r41_pif2lif) ];

}

1;
