###############################################################################
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
###############################################################################
# Licensed Materials - Property of IBM
#
#  5724-T01 5724-S98 5724-T03 5724-S96
#
# (c) Copyright IBM Corp. 2003, 2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

use AudLog;

$r51_rules = [


    ## [START] IpAccessHostGpb
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC => 'Accumulate the IpSystem_IpAccessHostGpb counters',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-IpSystem_IpAccessHostGpb-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_SORT_ON   => [],
        NON_ADDITIVE_COUNTERS => [qw(userLabel ManagedElement IpAccessHostGpb)],
		OLD_COUNTER_NAMES => [ qw(pmIpInAddrErrors pmIpInDiscards pmIpInHdrErrors pmIpInReceives pmIpInUnknownProtos pmIpOutDiscards pmIpOutRequests) ],
        
		NEW_COUNTER_NAMES => [ qw(IpAHG_pmIpInAddrErrors IpAHG_pmIpInDiscards IpAHG_pmIpInHdrErrors IpAHG_pmIpInReceives IpAHG_pmIpInUnknownProtos IpAHG_pmIpOutDiscards IpAHG_pmIpOutRequests) ],

        OUTPUT_BLOCK_NAME     => 'IpSystem_IpAccessHostGpb',
    },
    ## [END] IpAccessHostGpb

    ## [START] M3uAssociation (Ansi) (Not tested with real data)
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join TransportNetwork_Mtp3bSpAnsi_M3uAssociation files',
        INPUT_FILE_DESCRIPTION => [
			'^ManagedElement_TransportNetwork_Mtp3bSpAnsi_M3uAssociation-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Mtp3bSpAnsi_M3uAssociation',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(userLabel M3uAssociation)],
        OUTPUT_FILENAME_START => 'TransportNetwork_Mtp3bSpAnsi_M3uAssociation',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
    ## [END] M3uAssociation (Ansi)

    ## [START] TransportNetwork_Mtp3bSpChina_M3uAssociation
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join TransportNetwork_Mtp3bSpChina_M3uAssociation files',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Mtp3bSpChina_M3uAssociation-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Mtp3bSpChina_M3uAssociation',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(userLabel M3uAssociation)],
        OUTPUT_FILENAME_START => 'TransportNetwork_Mtp3bSpChina_M3uAssociation',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
          [qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC =>
			'Accumulate the TransportNetwork_Mtp3bSpChina_M3uAssociation joined counters',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Mtp3bSpChina_M3uAssociation-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_SORT_ON   => [qw(userLabel M3uAssociation)],
        NON_ADDITIVE_COUNTERS => [qw(userLabel M3uAssociation)],
		OLD_COUNTER_NAMES => [ qw(pmNoOfDataMsgRec pmNoOfDataMsgSent pmNoOfRecUserData pmNoOfSentUserData) ],
		NEW_COUNTER_NAMES => [ qw(M3uA_pmNoOfDataMsgRec M3uA_pmNoOfDataMsgSent M3uA_pmNoOfRecUserData M3uA_pmNoOfSentUserData) ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Mtp3bSpChina_M3uAssociation',
    },
    ## [END] TransportNetwork_Mtp3bSpChina_M3uAssociation

    ## [START] TransportNetwork_Mtp3bSpTtc_M3uAssociation
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join TransportNetwork_Mtp3bSpTtc_M3uAssociation files',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Mtp3bSpTtc_M3uAssociation-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Mtp3bSpTtc_M3uAssociation',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(userLabel M3uAssociation)],
        OUTPUT_FILENAME_START => 'TransportNetwork_Mtp3bSpTtc_M3uAssociation',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
	{
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC =>
			'Accumulate the TransportNetwork_Mtp3bSpTtc_M3uAssociation joined counters',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Mtp3bSpTtc_M3uAssociation-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_SORT_ON   => [qw(userLabel M3uAssociation)],
        NON_ADDITIVE_COUNTERS => [qw(userLabel M3uAssociation)],
		OLD_COUNTER_NAMES => [ qw(pmNoOfDataMsgRec pmNoOfDataMsgSent pmNoOfRecUserData pmNoOfSentUserData) ],
		NEW_COUNTER_NAMES => [ qw(M3uA_pmNoOfDataMsgRec M3uA_pmNoOfDataMsgSent M3uA_pmNoOfRecUserData M3uA_pmNoOfSentUserData) ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Mtp3bSpTtc_M3uAssociation',
    },
    ## [END] TransportNetwork_Mtp3bSpTtc_M3uAssociation


    ## [START] Aal2Ap
    {
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join TransportNetwork_Aal2Sp_Aal2Ap files',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Aal2Sp_Aal2Ap-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Aal2Sp_Aal2Ap',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(userLabel Aal2Ap)],
        OUTPUT_FILENAME_START => 'TransportNetwork_Aal2Sp_Aal2Ap',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC =>
			'Accumulate the TransportNetwork_Aal2Sp_Aal2Ap joined counters',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Aal2Sp_Aal2Ap-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
		COUNTERS_TO_SORT_ON   => [],
        NON_ADDITIVE_COUNTERS => [
			qw(ManagedElement TransportNetwork DChannel_Tp Aal2Sp userLabel IUA_App_Server Unknown_RemoteSite)
        ],
		
		OLD_COUNTER_NAMES => [ qw(pmSuccInConnsRemoteQosClassA pmSuccOutConnsRemoteQosClassA pmUnRecMessages pmUnSuccInConnsLocalQosClassA pmUnSuccInConnsRemoteQosClassA pmUnSuccOutConnsRemoteQosClassA) ],
        
		NEW_COUNTER_NAMES => [ qw(Aal2Ap_pmSuccInConnsRemoteQosClassA Aal2Ap_pmSuccOutConnsRemoteQosClassA Aal2Ap_pmUnRecMessages Aal2Ap_pmUnSuccInConnsLocalQosClassA Aal2Ap_pmUnSuccInConnsRemoteQosClassA Aal2Ap_pmUnSuccOutConnsRemoteQosClassA) ],
		
        OUTPUT_BLOCK_NAME  => 'TransportNetwork_Aal2Sp_Aal2Ap',
    },
    ## [END] Aal2Ap

  

    ## [START] UnknownRemoteSite
    {
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join MgwApplication_UnknownRemoteSite files',
        INPUT_FILE_DESCRIPTION => [
			'^MgwApplication_UnknownRemoteSite-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'MgwApplication_UnknownRemoteSite',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(Unknown_RemoteSite)],
        OUTPUT_FILENAME_START => 'MgwApplication_UnknownRemoteSite',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },

    ## [START] Changes for Ericsson MGW R5.1 Maintenance Release ##
    {
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Complex KPI for Hi Lo Octets counters',
        INPUT_FILE_DESCRIPTION =>
          [ '^MgwApplication_UnknownRemoteSite-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif', ],
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            $c_ref->{TotRtpSentOctets}  = (2147483648 * $c_ref->{pmRtpSentOctetsHi}) + $c_ref->{pmRtpSentOctetsLo};
            $c_ref->{TotRtpReceivedOctets}  = (2147483648 * $c_ref->{pmRtpReceivedOctetsHi}) + $c_ref->{pmRtpReceivedO
ctetsLo};
            $c_ref->{TotRtpSentPkts}  = (2147483648 * $c_ref->{pmRtpSentPktsHi}) + $c_ref->{pmRtpSentPktsLo};
            $c_ref->{TotRtpReceivedPkts}  = (2147483648 * $c_ref->{pmRtpReceivedPktsHi}) + $c_ref->{pmRtpReceivedPktsL
o};
            $c_ref->{TotSuccTransmittedPkts}  = (2147483648 * $c_ref->{pmSuccTransmittedPktsHi}) + $c_ref->{pmSuccTran
smittedPktsLo};

            return 0;
        },
        FILENAME_SUFFIX           => 'PZ',
        REDUNDANT_DATA_COUNTERS   => [],
        REDUNDANT_HEADER_COUNTERS => [],
    },

    ## [END] Changes for Ericsson MGW R5.1 Maintenance Release ##

    {
        RULE_TYPE => 'UNPEGGER',
        RULE_DESC => 'Unpeg MgwApplication_UnknownRemoteSite counter values ',
        INPUT_FILE_DESCRIPTION =>
			'^(MgwApplication_UnknownRemoteSite-#-.+?)-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}.*-J-#-PZ\.pif',
        INPUT_FILE_DATETIME_KEY =>
			'^MgwApplication_UnknownRemoteSite-#-.+?-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J-#-PZ\.pif',
        PEG_FILENAME_PREFIX   => 'SAVED',
        UNPEG_FILENAME_PREFIX => 'UNPEG',
        UNPEG_FILE_TYPE       => 'HEADER',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        KEEP_RAW_GRANULARITY  => 'True',
        MAX_PEG_PIF_AGE       => 'DURATION*4+60',
        CALCULATE_ROLLOVER    => 'True',
        DEFAULT_NULL_VALUE    => '',
        DATETIME_COUNTERS     => {
            STARTTIME => 'StartTime',
            STARTDATE => 'StartDate',
            DURATION  => 'granularityPeriod',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON => [qw (nEDistinguishedName_MeContext ManagedElement UnknownRemoteSite)],
        PEG_COUNTERS => {
            'pmCallsWithRtpPacketLoss0'    => '2147483647',
            'pmCallsWithRtpPacketLoss1'    => '2147483647',
            'pmCallsWithRtpPacketLoss2'    => '2147483647',
            'pmCallsWithRtpPacketLoss3'    => '2147483647',
            'pmCallsWithRtpPacketLoss4'    => '2147483647',
            'pmCallsWithRtpPacketLoss5'    => '2147483647',
            'pmCallsWithRtpPacketLoss6'    => '2147483647',
            'pmConnLatePktsRatio0'         => '2147483647',
            'pmConnLatePktsRatio1'         => '2147483647',
            'pmConnLatePktsRatio2'         => '2147483647',
            'pmConnLatePktsRatio3'         => '2147483647',
            'pmConnLatePktsRatio4'         => '2147483647',
            'pmConnLatePktsRatio5'         => '2147483647',
            'pmConnLatePktsRatio6'         => '2147483647',
            'pmConnMeasuredJitter0'        => '2147483647',
            'pmConnMeasuredJitter1'        => '2147483647',
            'pmConnMeasuredJitter2'        => '2147483647',
            'pmConnMeasuredJitter3'        => '2147483647',
            'pmConnMeasuredJitter4'        => '2147483647',
            'pmConnMeasuredJitter5'        => '2147483647',
            'pmConnMeasuredJitter6'        => '2147483647',
            'pmConnMeasuredJitter7'        => '2147483647',
            'pmConnMeasuredJitter8'        => '2147483647',
            'pmIpReceivedEcnPkts'          => '2147483647',
            'pmLatePktsDueToDeJitter'      => '2147483647',
            'pmRtpDiscardedPkts'           => '2147483647',
            'pmRtpLostPkts'                => '2147483647',
            'pmRtpReceivedDscpCongPackets' => '2147483647',
            'pmRtpReceivedOctetsHi'        => '2147483647',
            'pmRtpReceivedOctetsLo'        => '2147483647',
            'pmRtpReceivedPktsHi'          => '2147483647',
            'pmRtpReceivedPktsLo'          => '2147483647',
            'pmRtpSentOctetsHi'            => '2147483647',
            'pmRtpSentOctetsLo'            => '2147483647',
            'pmRtpSentPktsHi'              => '2147483647',
            'pmRtpSentPktsLo'              => '2147483647',
            'pmSuccTransmittedPktsHi'      => '2147483647',
            'pmSuccTransmittedPktsLo'      => '2147483647',
        }
    },
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC =>
			'Accumulate the MgwApplication_UnknownRemoteSite joined counters',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-MgwApplication_UnknownRemoteSite-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J-#-PZ\.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_SORT_ON   => [],
        NON_ADDITIVE_COUNTERS => [
            qw(userLabel UnknownRemoteSite ManagedElement MgwApplication TransportNetwork)
        ],
		
		OLD_COUNTER_NAMES => [ qw(pmRtpDiscardedPkts pmRtpLostPkts pmRtpReceivedOctetsHi pmRtpReceivedOctetsLo pmRtpReceivedPktsHi pmRtpReceivedPktsLo pmRtpSentOctetsHi pmRtpSentOctetsLo pmRtpSentPktsHi pmRtpSentPktsLo) ],

		NEW_COUNTER_NAMES => [ qw(URSite_pmRtpDiscardedPkts URSite_pmRtpLostPkts URSite_pmRtpReceivedOctetsHi URSite_pmRtpReceivedOctetsLo URSite_pmRtpReceivedPktsHi URSite_pmRtpReceivedPktsLo URSite_pmRtpSentOctetsHi URSite_pmRtpSentOctetsLo URSite_pmRtpSentPktsHi URSite_pmRtpSentPktsLo) ],
		
        OUTPUT_BLOCK_NAME  => 'MgwApplication_UnknownRemoteSite',
    },
    ## [END] UnknownRemoteSite

    ## [START] Sctp
    {
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join TransportNetwork_Sctp files',
        INPUT_FILE_DESCRIPTION => [
			'^TransportNetwork_Sctp-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME     => 'TransportNetwork_Sctp',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_JOIN_ON   => [qw(Sctp)],
        OUTPUT_FILENAME_START => 'TransportNetwork_Sctp',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
	
	{
        RULE_TYPE => 'UNPEGGER',
        RULE_DESC => 'Unpeg TransportNetwork_Sctp counter values ',
        INPUT_FILE_DESCRIPTION => '^(TransportNetwork_Sctp-#-.+?)-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}.*-J.pif',
        INPUT_FILE_DATETIME_KEY => '^TransportNetwork_Sctp-#-.+?-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        PEG_FILENAME_PREFIX   => 'SAVED',
        UNPEG_FILENAME_PREFIX => 'UNPEG',
        UNPEG_FILE_TYPE       => 'HEADER',
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        KEEP_RAW_GRANULARITY  => 'True',
        MAX_PEG_PIF_AGE       => 'DURATION*4+60',
        CALCULATE_ROLLOVER    => 'True',
        DEFAULT_NULL_VALUE    => '',
        DATETIME_COUNTERS     => {
            STARTTIME => 'StartTime',
            STARTDATE => 'StartDate',
            DURATION  => 'granularityPeriod',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON => [qw(nEDistinguishedName_MeContext Sctp)],
        PEG_COUNTERS => {
			'pmSctpAborted' => '2147483647',
			'pmSctpActiveEstab' => '2147483647',
			#'pmSctpCurrEstab' => '2147483647',
			'pmSctpPassiveEstab' => '2147483647',
			'pmSctpShutdowns' => '2147483647',
			'pmSctpStatAssocOutOfBlue' => '2147483647',
			'pmSctpStatChecksumErrorCounter' => '2147483647',
			'pmSctpStatCommResume' => '2147483647',
			'pmSctpStatCommStop' => '2147483647',
			'pmSctpStatFragmentedUserMsg' => '2147483647',
			'pmSctpStatOutOfOrderRecChunks' => '2147483647',
			'pmSctpStatOutOfOrderSendChunks' => '2147483647',
			'pmSctpStatReassembledUserMsg' => '2147483647',
			'pmSctpStatRecChunks' => '2147483647',
			'pmSctpStatRecChunksDropped' => '2147483647',
			'pmSctpStatReceivedControlChunks' => '2147483647',
			'pmSctpStatReceivedPackages' => '2147483647',
			'pmSctpStatRetransChunks' => '2147483647',
			'pmSctpStatSentChunks' => '2147483647',
			'pmSctpStatSentChunksDropped' => '2147483647',
			'pmSctpStatSentControlChunks' => '2147483647',
			'pmSctpStatSentPackages' => '2147483647',
		}
    },
	
	{
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC => 'Accumulate the TransportNetwork_Sctp counters',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_Sctp-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-J.pif',
        ],
        PRODUCE_PIF           => 'True',
        PRODUCE_LIF           => 0,
        COUNTERS_TO_SORT_ON   => [],
        NON_ADDITIVE_COUNTERS => [
            qw(userLabel Sctp ManagedElement MgwApplication TransportNetwork)
        ],
		
		OLD_COUNTER_NAMES => [ qw(pmSctpStatRecChunks pmSctpStatRecChunksDropped pmSctpStatReceivedControlChunks pmSctpStatReceivedPackages pmSctpStatRetransChunks pmSctpStatSentChunks pmSctpStatSentChunksDropped pmSctpStatSentControlChunks pmSctpStatSentPackages) ],

		NEW_COUNTER_NAMES => [ qw(Sctp_pmSctpStatRecChunks Sctp_pmSctpStatRecChunksDropped Sctp_pmSctpStatReceivedControlChunks Sctp_pmSctpStatReceivedPackages Sctp_pmSctpStatRetransChunks Sctp_pmSctpStatSentChunks Sctp_pmSctpStatSentChunksDropped Sctp_pmSctpStatSentControlChunks Sctp_pmSctpStatSentPackages) ],
		
        OUTPUT_BLOCK_NAME  => 'TransportNetwork_Sctp',
    },
    ## [END] Sctp

    ## [START] IuaApplicationServer
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC =>
			'Join ManagedElement_AccessSignalling_IuaApplicationServer files',
        INPUT_FILE_DESCRIPTION => [
			'^ManagedElement_AccessSignalling_IuaApplicationServer-#-(.+?-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}).*-I.pif',
        ],
        OUTPUT_BLOCK_NAME =>
			'ManagedElement_AccessSignalling_IuaApplicationServer',
        PRODUCE_PIF         => 'True',
        PRODUCE_LIF         => 0,
        COUNTERS_TO_JOIN_ON => [qw(IuaApplicationServer)],
        OUTPUT_FILENAME_START => 'ManagedElement_AccessSignalling_IuaApplicationServer',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[qw(nEDistinguishedName_MeContext StartDate StartTime)],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
    ## [END] IuaApplicationServer

];
