###############################################################################
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
###############################################################################
# Licensed Materials - Property of IBM
#
#  5724-T01 5724-S98 5724-T03 5724-S96
#
# (c) Copyright IBM Corp. 2003, 2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

package UserConfig;

@ISA    = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();

my $r41_unpeg      = do "r41_unpeg.rules";
my $r41_unpeg_join = do "r41_unpeg_join.rules";

## added to support r5.1
my $r51_rules       = do "r51_rules.pm";
my $r51_rules_unpeg = do "r51_rules_unpeg.pm";

my @r41_rules = (

    #Process atmTrafficDescriptor
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Extract ATM Traffic Descriptor',
        INPUT_FILE_DESCRIPTION => ['^UNPEG-#-TransportNetwork_AtmPort.*-#-J.pif',
        			   '^TransportNetwork_AtmPort.*-#-J.pif',  # added in R5.1 maintenance release b2
                                  ],
        DATA_COUNTERS_OP       => sub {
            my $c_ref = shift;

          #basically extract the atmTrafficDescriptor after DDM had a go at them
            my @fields = grep /atmTrafficDescriptor/i, keys %$c_ref;
            my @vals = map { $c_ref->{$_} } @fields;
            my @descr = grep /AtmTrafficDescriptor(Id)?=/i, @vals;

           #normalise AtmTrafficDescriptor-type fields to AtmTrafficDescriptorId
            if ( scalar(@descr) > 0 ) {
                $descr[0] =~ s/AtmTrafficDescriptor(Id)?=//g;
                $c_ref->{AtmTrafficDescriptorId} = $descr[0];
            }
            map { delete $c_ref->{$_} } @fields;

            return 0;
        },
        FILENAME_SUFFIX           => 'PZ',
        REDUNDANT_DATA_COUNTERS   => [],
        REDUNDANT_HEADER_COUNTERS => [],
    },


    ## below is commented during maintenance release cycle
    #{
    #    RULE_TYPE => 'PERLIZE',
    #    RULE_DESC => 'Copy PCR info',
    #    INPUT_FILE_DESCRIPTION => '^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-I.pif',
    #    DATA_COUNTERS_OP => sub {
    #        my $c_ref = shift;
    #        $c_ref->{egressPcr}  = $c_ref->{egressAtmPcr};
    #        $c_ref->{ingressPcr} = $c_ref->{ingressAtmPcr};
    #        $c_ref->{egressatmpcr}  = $c_ref->{egressAtmPcr};
    #        $c_ref->{ingressatmpcr} = $c_ref->{ingressAtmPcr};
    #        return 0;
    #    },
    #    FILENAME_SUFFIX           => 'PZ',
    #    REDUNDANT_DATA_COUNTERS   => [],
    #    REDUNDANT_HEADER_COUNTERS => [],
    #},

    #Inject ingress, egress info
    {
        RULE_TYPE              => 'INFOINSERT',
        RULE_DESC              => 'Inject AtmTrafficDescriptor info',
        INPUT_FILE_DESCRIPTION => [
            #'^UNPEG-#-TransportNetwork_AtmPort\w*-#-(.*)-#-(?:\d+)-.*-#-PZ.pif', ##original is not commented
			#'^UNPEG-#-TransportNetwork_AtmPort[\_\w]*-#-(.*)-#-(?:\d+)-.*-#-J-#-PZ.pif',
			'^UNPEG-#-TransportNetwork_AtmPort.*-#-(.*)-#-(?:\d+)-.*-J-#-PZ.pif',
                        '^TransportNetwork_AtmPort.*-#-(.*)-#-(?:\d+)-.*-J-#-PZ.pif', # added in R5.1 maintenance release b2
			#~ '^UNPEG-#-TransportNetwork_AtmPort_VplTp-#-(.*)-#-(?:\d+)-#-J-#-PZ.pif', ##originally commented
			#~ '^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-(.*)-#-(?:\d+)-#-J-#-PZ.pif', ##originally commented
			#~ '^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-(.*)-#-(?:\d+)-.*J.pif' ##originally commented
        ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD =>
			[ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        NAMES_USED_TO_ID_DATA_RECORD => ['AtmTrafficDescriptorId'],
        INFO_FILE_DESCRIPTION        => [
			'^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-I-#-PZ.pif'
        ],
        HEADER_NAMES_USED_TO_ID_INFORMATION =>
			[ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        NAMES_USED_TO_ID_INFORMATION => ['AtmTrafficDescriptorId'],
        REDUNDANT_COUNTERS =>
			[ 'AtmTrafficDescriptor', 'Record_measurement_count' ],
        WRITE_DATA_LINE => 'True',
        PRODUCE_PIF     => 'True',
        PRODUCE_LIF     => 0,
    },

    ## [START] PDF (Probability Density Function) counters support (added for r5.1)
    {
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Extracting and assigning PDF counters',
        INPUT_FILE_DESCRIPTION => [
			'TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-.*-#-J-#-PZ-#-S\.pif',
		],

        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

            ### Split pmBwUtilizationRx into individual counters
			if ($c_ref->{pmBwUtilizationRx}) {
				my @pmBwUtilizationRx_cnames = (
					qw(pmBwUtilRx_PCR pmBwUtilRx_0_5 pmBwUtilRx_6_10 pmBwUtilRx_11_15 pmBwUtilRx_16_20 pmBwUtilRx_21_25 pmBwUtilRx_26_30 pmBwUtilRx_31_35 pmBwUtilRx_36_40 pmBwUtilRx_41_45 pmBwUtilRx_46_50 pmBwUtilRx_51_55 pmBwUtilRx_56_60 pmBwUtilRx_61_65 pmBwUtilRx_66_70 pmBwUtilRx_71_75 pmBwUtilRx_76_80 pmBwUtilRx_81_85 pmBwUtilRx_86_90 pmBwUtilRx_91_95 pmBwUtilRx_96_100)
				);
				my @pmBwUtilizationRx_cvals = split( ",", $c_ref->{pmBwUtilizationRx} );
				foreach my $cname (@pmBwUtilizationRx_cnames) {
					$c_ref->{$cname} = shift @pmBwUtilizationRx_cvals;
				}

				delete $c_ref->{pmBwUtilizationRx};
			}

            ### Split pmBwUtilizationTx into individual counters
			if ($c_ref->{pmBwUtilizationTx}) {
				my @pmBwUtilizationTx_cnames = (
					qw(pmBwUtilTx_PCR pmBwUtilTx_0_5 pmBwUtilTx_6_10 pmBwUtilTx_11_15 pmBwUtilTx_16_20 pmBwUtilTx_21_25 pmBwUtilTx_26_30 pmBwUtilTx_31_35 pmBwUtilTx_36_40 pmBwUtilTx_41_45 pmBwUtilTx_46_50 pmBwUtilTx_51_55 pmBwUtilTx_56_60 pmBwUtilTx_61_65 pmBwUtilTx_66_70 pmBwUtilTx_71_75 pmBwUtilTx_76_80 pmBwUtilTx_81_85 pmBwUtilTx_86_90 pmBwUtilTx_91_95 pmBwUtilTx_96_100)
				);
				my @pmBwUtilizationTx_cvals = split( ",", $c_ref->{pmBwUtilizationTx} );
				foreach my $cname (@pmBwUtilizationTx_cnames) {
					$c_ref->{$cname} = shift @pmBwUtilizationTx_cvals;
				}

				delete $c_ref->{pmBwUtilizationTx};
			}

            return 0;
        },
        FILENAME_SUFFIX           => 'PZ',
        REDUNDANT_DATA_COUNTERS   => [],
        REDUNDANT_HEADER_COUNTERS => [],
    },
    ## [END] PDF (Probability Density Support) counters support (added for r5.1)

	#TransportNetwork_AtmPort_VplTp_VpcTp aggregation
	{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join TransportNetwork_AtmPort_VplTp_VpcTp',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ-#-S.pif'
        ],
        OUTPUT_BLOCK_NAME       => 'TransportNetwork_AtmPort_VplTp_VpcTp',
        PRODUCE_PIF             => 'True',
        PRODUCE_LIF             => 'True',
        REDUNDANT_DATA_COUNTERS => [],
        COUNTERS_TO_JOIN_ON     => [ 'AtmPort', 'VplTp' ],
        OUTPUT_FILENAME_START   => 'TransportNetwork_AtmPort_VplTp_VpcTp',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
	#{
        #RULE_TYPE => 'ACCUMULATE',
        #RULE_DESC => 'Accumulate the VpcTp counters',
        #INPUT_FILE_DESCRIPTION => [
			#'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ-#-S.pif'
		#],
		#PRODUCE_PIF         => 'True',
        #PRODUCE_LIF         => 'True',
        #COUNTERS_TO_SORT_ON => [ 'AtmPort', 'VplTp' ],
        #NON_ADDITIVE_COUNTERS => [ 'ManagedElement', 'TransportNetwork', 'userLabel', 'suspectFlag', ],
        #REDUNDANT_COUNTERS => [qw(VpcTp)],
        #OUTPUT_BLOCK_NAME  => 'TransportNetwork_AtmPort_VplTp_VpcTp',
    #},

    #Aggregation for TransportNetwork_AtmPort_VplTp_VpcTp upto Vpl level
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC => 'Accumulate the VpcTp counters up to Vpl level',
        INPUT_FILE_DESCRIPTION => [
			#'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ.pif' ## commented and fixed as below on r5.1
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ-#-S.pif'
		],
		PRODUCE_PIF         => 'True',
        PRODUCE_LIF         => 0,
        COUNTERS_TO_SORT_ON => [ 'AtmPort', 'VplTp' ],
        NON_ADDITIVE_COUNTERS => [ 'ManagedElement', 'TransportNetwork', 'userLabel', 'suspectFlag', ],
        REDUNDANT_COUNTERS => [qw(VpcTp)],
        OUTPUT_BLOCK_NAME  => 'TransportNetwork_AtmPort_VplTp',
    },

    #Inject aggregaeted counters into TransportNetwork_AtmPort_VplTp
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Inject aggregated counters into TransportNetwork_AtmPort_VplTp',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-(.*)-#-(?:\d+)-.*-#-TransportNetwork_AtmPort_VplTp-#-A.pif',
			'^TransportNetwork_AtmPort_VplTp-#-(.*)-#-(?:\d+)-.*-#-S.pif'
        ],
        OUTPUT_BLOCK_NAME       => 'TransportNetwork_AtmPort_VplTp',
        PRODUCE_PIF             => 'True',
        PRODUCE_LIF             => 0,
        REDUNDANT_DATA_COUNTERS => [qw(VpcTp)],
        COUNTERS_TO_JOIN_ON     => [ 'AtmPort', 'VplTp' ],
        OUTPUT_FILENAME_START   => 'TransportNetwork_AtmPort_VplTp',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },

# commented in R5.1 maintenance release b2
#    {
#        RULE_TYPE => 'PIF_2_LIF',
#        RULE_DESC => 'Output VplTp aggregated LIFs',
#        INPUT_FILE_DESCRIPTION => ['^TransportNetwork_AtmPort_VplTp-.*-#-J.pif'],
#        PRODUCE_PIF => 0,
#        PRODUCE_LIF => 'True',
#    },

    #Aggregation for TransportNetwork_AtmPort_VplTp_VpcTp upto AtmPort level
    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC => 'Accumulate the VpcTp counters upto AtmPort level',
        INPUT_FILE_DESCRIPTION => [
			# '^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ.pif' ## commented on r5.1
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-.*-#-PZ-#-S.pif'
		],
        PRODUCE_PIF         => 'True',
        PRODUCE_LIF         => 0,
        COUNTERS_TO_SORT_ON => ['AtmPort'],
        NON_ADDITIVE_COUNTERS =>
			[ 'ManagedElement', 'TransportNetwork', 'userLabel', 'suspectFlag' ],
        REDUNDANT_COUNTERS => [qw(VpcTp VplTp)],
		OUTPUT_BLOCK_NAME  => 'TransportNetwork_AtmPort',
    },

    #Inject aggregated counters into TransportNetwork_AtmPort
    {
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Inject aggregated counters into TransportNetwork_AtmPort_VplTp',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-(.*)-#-(?:\d+)-.*-#-TransportNetwork_AtmPort-#-A.pif',
            '^UNPEG-#-TransportNetwork_AtmPort-#-(.*)-#-(?:\d+)-.*-#-S.pif',
            '^TransportNetwork_AtmPort-#-(.*)-#-(?:\d+)-.*-#-S.pif' # Added in R5.1 maintenance release B2
        ],
        OUTPUT_BLOCK_NAME       => 'TransportNetwork_AtmPort',
        PRODUCE_PIF             => 'True',
        PRODUCE_LIF             => 0,
        REDUNDANT_DATA_COUNTERS => [qw( VpcTp VplTp)],
        COUNTERS_TO_JOIN_ON     => ['AtmPort'],
        OUTPUT_FILENAME_START   => 'TransportNetwork_AtmPort',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
			[ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },

    {
        RULE_TYPE              => 'PIF_2_LIF',
        RULE_DESC              => 'Output AtmPort aggregated LIFs',
        INPUT_FILE_DESCRIPTION => ['^TransportNetwork_AtmPort-.*-#-J.pif'],
        PRODUCE_PIF            => 0,
        PRODUCE_LIF            => 'True',
    },
    {
        RULE_TYPE              => 'PIF_2_LIF',
        RULE_DESC              => 'Output AtmTrafficDescriptor info',
        INPUT_FILE_DESCRIPTION => ['^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-I-#-PZ.pif'],
        PRODUCE_PIF => 0,
        PRODUCE_LIF => 'True',
    },

    {
        RULE_TYPE              => 'PIF_REMOVE',
        RULE_DESC              => 'Remove the above initial PIFS',
        INPUT_FILE_DESCRIPTION => [
            '^UNPEG-#-TransportNetwork_AtmPort.*-#-J.pif',
            '^TransportNetwork_AtmPort.*-#-J.pif', # added in R5.1 maintenance release b2
            '^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-I-#-PZ.pif',
            '^TransportNetwork_AtmTrafficDescriptor-#-(.*)-#-(?:\d+)-#-I.pif'
        ],
    },

    #Aggregation for MgwApplication_Aggregated
    {
        'RULE_TYPE' => 'TRANSPLANT_HEAD',
        'RULE_DESC' => 'Transplant Header information into the Vmgw Data records',
        'INPUT_FILE_DESCRIPTION' => [ "^UNPEG-#-MgwApplication(_(Vmgw|TdmTermGrp))?-.*-#-J.pif", ],
        'HEADER_COUNTERS_FOR_TRANSPLANT' => [ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        'PRODUCE_PIF' => 'True',
        'PRODUCE_LIF' => 0,
        'OUTPUT_FORMAT' => 0,    #disable the writing of -#-TH.pt files to output directory
    },

    {
        'RULE_TYPE' => 'ACCUMULATE',
        'RULE_DESC' => 'Accumulate the TDMTermGrp up to MGW level',
        'INPUT_FILE_DESCRIPTION' =>
          ["^UNPEG-#-MgwApplication_TdmTermGrp-.*-#-TH.pif"],
        'PRODUCE_PIF'           => 'True',
        'PRODUCE_LIF'           => 0,
        'COUNTERS_TO_SORT_ON'   => ['nEDistinguishedName_MeContext'],
        'NON_ADDITIVE_COUNTERS' => ['ManagedElement', 'TdmTermGrp', 'MgwApplication', 'userLabel', 'suspectFlag'],
        'OLD_COUNTER_NAMES' => [qw(pmNrOfTdmTermsRej pmNrOfTdmTermsReq)],
        'NEW_COUNTER_NAMES' => [qw(TDMGrp_pmNrOfTdmTermsRej TDMGrp_pmNrOfTdmTermsReq)],
        'REDUNDANT_COUNTERS' => ['pmNrOfTdmTermsBusy'],
        'OUTPUT_BLOCK_NAME'  => 'MgwApplication_Aggregated',
    },

    {
        'RULE_TYPE' => 'ACCUMULATE',
        'RULE_DESC' => 'Accumulate the Vmgw up to MGW level',
        'INPUT_FILE_DESCRIPTION' => ["^UNPEG-#-MgwApplication_Vmgw-.*-#-TH.pif"],
        'PRODUCE_PIF'           => 'True',
        'PRODUCE_LIF'           => 0,
        'COUNTERS_TO_SORT_ON'   => ['nEDistinguishedName_MeContext'],
        'NON_ADDITIVE_COUNTERS' => [
            'ManagedElement', 'TdmTermGrp', 'MgwApplication', 'userLabel',
            'suspectFlag'
        ],
        'OLD_COUNTER_NAMES' => [
            qw(pmNrOfAal2TermsRej pmNrOfAal2TermsReq pmNrOfIpTermsReq pmNrOfIpTermsRej pmNrOfGcpNotifyCsdFaultAEst pmNrOfGcpNotifySpeechFaultAEst )
        ],
        'NEW_COUNTER_NAMES' => [
            qw (VMGW_pmNrOfAal2TermsRej VMGW_pmNrOfAal2TermsReq VMGW_pmNrOfIpTermsReq VMGW_pmNrOfIpTermsRej VMGW_pmNrOfGcpNotifyCsdFaultAEst VMGW_pmNrOfGcpNotifySpeechFaultAEst )
        ],
        'OUTPUT_BLOCK_NAME' => 'MgwApplication_Aggregated',
    },

    {
        RULE_TYPE => 'ACCUMULATE',
        RULE_DESC => 'MgwApplication_Aggregated From MgwApplication',
        INPUT_FILE_DESCRIPTION => ['^UNPEG-#-MgwApplication-.*-#-TH.pif'],
        'PRODUCE_PIF'          => 'True',
        'PRODUCE_LIF'          => 0,
        'COUNTERS_TO_SORT_ON'  => ['nEDistinguishedName_MeContext'],
        'OUTPUT_BLOCK_NAME'    => 'MgwApplication_Aggregated',
    },

    {
        RULE_TYPE              => 'JOIN',
        RULE_DESC              => 'Join the MgwApplication_Aggregated files ',
        INPUT_FILE_DESCRIPTION => [
			'^UNPEG-#-MgwApplication-#-(.*)-#-(?:\d+)-.*-#-MgwApplication_Aggregated-#-A.pif',
			'^UNPEG-#-MgwApplication_Vmgw-#-(.*)-#-(?:\d+)-.*-#-MgwApplication_Aggregated-#-A.pif',
			'^UNPEG-#-MgwApplication_TdmTermGrp-#-(.*)-#-(?:\d+)-.*-#-MgwApplication_Aggregated-#-A.pif',
        ],
        OUTPUT_BLOCK_NAME       => 'MgwApplication_Aggregated',
        PRODUCE_PIF             => 'True',
        PRODUCE_LIF             => 0,
        REDUNDANT_DATA_COUNTERS => [
            qw(
              ManagedElement MgwApplication userLabel suspectFlag Vmgw
              pmUsedBandwidthForIpTransport
              pmNrOfMediaStreamChannelsReq
              pmNrOfEmergencyCalls
              pmNrOfRejsByStaticAdmCtrl
              pmNrOfRejEmcCalls
              maxNrOfLicMediaStreamChannels
              pmNrOfMediaStreamChannelsBusy
              pmNrOfTdmTermsBusy pmNrOfTdmTermsRej pmNrOfTdmTermsReq
              pmNrOfAal2TermsRej pmNrOfAal2TermsReq pmNrOfIpTermsReq
              pmNrOfIpTermsRej pmNrOfGcpNotifyCsdFaultAEst pmNrOfGcpNotifySpeechFaultAEst
              pmNrOfIuTermAal2BearEstabFailLoc
              pmNrOfRecIpbcpRejectMsg
              pmNrOfTermNbInitSucc
              pmNrOfRecIpbcpConfusedMsg
              pmNrOfOrigIpbcpBearSupervTmrExp
              pmNrOfGcpNotifyCsdFaultBEst
              pmGcpNrOfReceivedMessages
              pmNrOfNbTermAal2BearEstabFailLoc
              pmNrOfInternalAal2ConnEstabFail
              pmNrOfIuTermAal2BearEstabFailRem
              pmNrOfRecIpbcpAcceptMsg
              pmNrOfConnIcmpDestUnreachs
              pmNrOfTermIuInit
              pmNrOfGcpNotifySpeechFaultBEst
              pmNrOfTermIpbcpBearPrepRejected
              pmNrOfNbTermAal2BearEstabFailRem
              pmNrOfContextsRej
              pmNrOfGcpRetrans
              pmNrOfAal2TermsBusy
              pmNrOfOrigIpbcpBearPrepRejected
              pmNrOfContextsReq
              pmGcpNrOfSentMessages
              pmNrOfContextsBusy
              pmNrOfOrigNbInit
              pmNrOfSentIpbcpRequestMsg
              pmNrOfRecBctpProtocolFailures
              pmNrOfTermIuInitSucc
              pmNrOfGcpOctetsSent
              pmNrOfIpTermsBusy
              pmNrOfInvokedGcpLoadControl
              pmNoOfPCMOnNbConns
              pmNrOfSentIpbcpRejectMsg
              pmNrOfSentIpbcpConfusedMsg
              pmNrOfSentIpbcpAcceptMsg
              pmNoOfAMROnNbConns
              pmNrOfTermNbInit
              pmNrOfRecFaultyIpbcpAcceptMsg
              pmNoOfEFROnNbConns
              pmNrOfGcpSentPendingMess
              pmNrOfGcpTransactionWithMaxRetr
              pmNrOfGcpOctetsRec
              pmNrOfOrigNbInitFaults
              pmNrOfNbOrigAal2BearEstabFailLoc
              pmNrOfSentBctpProtocolFailures
              pmNrOfTermIpbcpBearSupervTmrExp
              pmGcpSystemUpTime
              pmNrOfRecIpbcpRequestMsg
              pmNrOfGcpTransWithMaxPendingMess
              pmNrOfNbOrigAal2BearEstabFailRem
              )
        ],
        COUNTERS_TO_JOIN_ON   => ['nEDistinguishedName_MeContext'],
        OUTPUT_FILENAME_START => 'MgwApplication_Aggregated',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME =>
          [ 'nEDistinguishedName_MeContext', 'StartDate', 'StartTime' ],
        REDUNDANT_HEADER_COUNTERS       => [],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
    },
    {
        RULE_TYPE => 'PIF_2_LIF',
        RULE_DESC => 'Write out the LIFs for MgwApplication_Aggregated',
        INPUT_FILE_DESCRIPTION => ['^MgwApplication_Aggregated.*-#-J.pif'],
        PRODUCE_PIF            => 0,
        PRODUCE_LIF            => 'True',
    },

    #END Aggregation for MgwApplication_Aggregated

    # START : BATCHING

# This 1st batching rule has many different blocks belonging to the same network_id.
# So, the batching is done with multiple blocks in one LIF file since each block has
# 1 block of information. This is different than the usual one where we want to combine
# based on a parent followed by its children for the same blockname.
# The batch is based on network_id + date + time interval. To test our NA loader endurance,
# we can try batching up at the date level and so on, if desired.

# BEGIN : UNPEG-#-MsProcessing files
# {
# RULE_TYPE               => 'BATCHFILES',
# RULE_DESC               => 'Batch UNPEG-#-MsProcessing files',
# INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-MsProcessing.*-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
# REDUNDANT_COUNTERS      => [],
# PRODUCE_PIF             => 0,
# OUTPUT_FORMAT           => 'LIF_Writer',
# OUTPUT_FILENAME_START   => 'BATCHED-UNPEG-#-MsProcessing',
# },
# Remove initial PIF after batching
# {
# RULE_TYPE                  => 'PIF_REMOVE',
# RULE_DESC                  => 'Remove UNPEG-#-MsProcessing pif',
# INPUT_FILE_DESCRIPTION     => ['^UNPEG-#-MsProcessing.*-#-.*-#-J.pif'],
# },
# END : UNPEG-#-MsProcessing files

# BEGIN : UNPEG-#-TransportNetwork_Mtp3bSpItu files
# {
# RULE_TYPE               => 'BATCHFILES',
# RULE_DESC               => 'Batch UNPEG-#-TransportNetwork_Mtp3bSpItu files',
# INPUT_FILE_DESCRIPTION  => ['^UNPEG-#-TransportNetwork_Mtp3bSpItu.*-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
# REDUNDANT_COUNTERS      => [],
# PRODUCE_PIF             => 0,
# OUTPUT_FORMAT           => 'LIF_Writer',
# OUTPUT_FILENAME_START   => 'BATCHED-UNPEG-#-TransportNetwork_Mtp3bSpItu',
# },

# Remove initial PIF after batching
# {
# RULE_TYPE                  => 'PIF_REMOVE',
# RULE_DESC                  => 'Remove UNPEG-#-TransportNetwork_Mtp3bSpItu pif',
# INPUT_FILE_DESCRIPTION     => ['^UNPEG-#-TransportNetwork_Mtp3bSpItu.*-#-.*-#-J.pif'],
# },
# END : UNPEG-#-TransportNetwork_Mtp3bSpItu files

# BEGIN : Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp files
# {
# RULE_TYPE               => 'BATCHFILES',
# RULE_DESC               => 'Batch  files',
# INPUT_FILE_DESCRIPTION  => ['^Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
# REDUNDANT_COUNTERS      => [],
# PRODUCE_PIF             => 0,
# OUTPUT_FORMAT           => 'LIF_Writer',
# OUTPUT_FILENAME_START   => 'BATCHED-Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp',
# },

# Remove initial PIF after batching
# {
# RULE_TYPE                  => 'PIF_REMOVE',
# RULE_DESC                  => 'Remove Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp pif',
# INPUT_FILE_DESCRIPTION     => ['^Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp.*-#-.*-#-I.pif'],
# },
# END : Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp files

    # END : BATCHING

    #blanket rules
    {
        RULE_TYPE              => 'PIF_2_LIF',
        RULE_DESC              => 'Convert All remaining UNPEG PIFs to LIFs',
        INPUT_FILE_DESCRIPTION => ['^UNPEG-#-.*-J.pif'],
        PRODUCE_PIF            => 0,
        PRODUCE_LIF            => 'True',
    },

# The PIF_2_LIF rule below won't happen because there are no files that end with #-J.pif. They instead end with initial ones
# the #-I.pif. So what happens is we get 1 block for each of the #-I.pif into LIFs. Rather than re-working the rule below,
# I only created a batch rule for the 1st input file type because it contained only 1 block. The other 3 input file
# descriptor has more than 1 block. No changes below except to explain why I created the last batch rule above.

    {
        RULE_TYPE              => 'PIF_2_LIF',
        RULE_DESC              => 'Convert All remaining UNPEG PIFs to LIFs',
        INPUT_FILE_DESCRIPTION => [
            '^Equipment_Subrack_Slot_PlugInUnit_Etm4_Os155SpiTtp-#-.*-J.pif',
            '^MsProcessing_MsDevicePool-#-.*-J.pif',
            '^E1PhysPathTerm-#-.*-J.pif',
            '^Equipment_Subrack_Slot_PlugInUnit-#-.*-J.pif',
            '^Ess_GigaBitEthernet-#-.*-J.pif', # R5.1 Maintenance FP B2
			'^TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-.*-#-PZ-#-S-#-PZ.pif', ## added for R5.1
			#'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-.*-#-PZ-#-S.pif', ## added for R5.1
			'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-.*-#-TransportNetwork_AtmPort_VplTp-#-A.pif',
                        '^UNPEG-#-FastEthernet-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
            		'^UNPEG-#-MgwApplication_IpNetwork_RemoteSite-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
            		'^TransportNetwork_AtmPort_VplTp_VpcTp_VclTp-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
           		'^TransportNetwork_AtmPort_VplTp-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
            		'^UNPEG-#-TransportNetwork_AtmPort_VplTp_VpcTp-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
           		'^UNPEG-#-MgwApplication_UnknownRemoteSite-#-.*-J-#-PZ.pif', # R5.1 Maintenance FP B2
        ],
        PRODUCE_PIF => 0,
        PRODUCE_LIF => 'True',
    },

    {
        RULE_TYPE              => 'PIF_2_LIF',
        RULE_DESC              => 'Convert All remaining PIFs to LIFs',
        INPUT_FILE_DESCRIPTION => ['^(?!SAVED-#-?).*-I.pif'],
        PRODUCE_PIF            => 0,
        PRODUCE_LIF            => 'True',
    },

    ## added based on CR valnt00063632
    {
        RULE_TYPE              => 'PIF_REMOVE',
        RULE_DESC              => 'Remove the rest of PIF',
        INPUT_FILE_DESCRIPTION => ['^(?!SAVED-#-?).*-I.pif',
        			   '^TransportNetwork_AtmPort_.*-J-#-PZ.pif'],
    },

);

my @dummy_rules = ();

sub postparser_config {

    #[ ( @$r41_unpeg_join, @$r41_unpeg, @r41_rules ) ];  ## as per r4.2

	## used for r5.1
    [ ( @$r41_unpeg_join, @$r41_unpeg, @$r51_rules, @$r51_rules_unpeg, @r41_rules ) ];

    #[ ( @dummy_rules ) ]; ## for debugging purposes

}

1;